@@ -3,7 +3,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2005-2007  Donald N. Allingham
-# Copyright (C) 2008-2009  Gary Burton 
+# Copyright (C) 2008-2009  Gary Burton
 # Copyright (C) 2009-2012  Doug Blank <doug.blank@gmail.com>
 # Copyright (C) 2011       Tim G L Lyons
 #
@@ -23,7 +23,7 @@
 #
 
 """
-This package implements access to GRAMPS configuration.
+This package implements access to Gramps configuration.
 """
 
 #---------------------------------------------------------------
@@ -31,7 +31,8 @@ This package implements access to GRAMPS configuration.
 # Gramps imports
 #
 #---------------------------------------------------------------
-import os, sys
+import os
+import re
 import logging
 
 #---------------------------------------------------------------
@@ -39,10 +40,14 @@ import logging
 # Gramps imports
 #
 #---------------------------------------------------------------
-from .const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
 from .const import HOME_DIR, USER_HOME, VERSION_DIR
 from .utils.configmanager import ConfigManager
+from .const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
+
+# _T_ is a gramps-defined keyword -- see po/update_po.py and po/genpot.sh
+def _T_(value): # enable deferred translations (see Python docs 22.1.3.4)
+    return value
 
 #---------------------------------------------------------------
 #
@@ -93,7 +98,7 @@ def save(filename=None):
     return CONFIGMAN.save(filename)
 
 def connect(key, func):
-    """ 
+    """
     Module shortcut to connect a key to a callback func.
     Returns a unique callback ID number.
     """
@@ -128,12 +133,11 @@ register('behavior.addmedia-relative-path', False)
 register('behavior.autoload', False)
 register('behavior.avg-generation-gap', 20)
 register('behavior.betawarn', False)
-register('behavior.check-for-updates', 0)
-register('behavior.check-for-update-types', ["new"])
-register('behavior.last-check-for-updates', "1970/01/01")
-register('behavior.previously-seen-updates', [])
-register('behavior.do-not-show-previously-seen-updates', True)
-register('behavior.database-path', os.path.join( HOME_DIR, 'grampsdb'))
+register('behavior.check-for-addon-updates', 0)
+register('behavior.check-for-addon-update-types', ["new"])
+register('behavior.last-check-for-addon-updates', "1970/01/01")
+register('behavior.previously-seen-addon-updates', [])
+register('behavior.do-not-show-previously-seen-addon-updates', True)
 register('behavior.date-about-range', 50)
 register('behavior.date-after-range', 50)
 register('behavior.date-before-range', 50)
@@ -147,18 +151,28 @@ register('behavior.recent-export-type', 3)
 register('behavior.spellcheck', False)
 register('behavior.startup', 0)
 register('behavior.surname-guessing', 0)
+register('behavior.translator-needed', True)
 register('behavior.use-tips', False)
 register('behavior.welcome', 100)
 register('behavior.web-search-url', 'http://google.com/#&q=%(text)s')
-register('behavior.addons-url', "https://raw.githubusercontent.com/gramps-project/addons/master/gramps42")
+register('behavior.addons-url', "https://raw.githubusercontent.com/gramps-project/addons/master/gramps50")
 
-register('export.proxy-order', [
-        ["privacy", 0], 
-        ["living", 0], 
-        ["person", 0], 
-        ["note", 0], 
-        ["reference", 0],
-        ])
+register('database.backend', 'bsddb')
+register('database.compress-backup', True)
+register('database.backup-path', USER_HOME)
+register('database.backup-on-exit', True)
+register('database.autobackup', 0)
+register('database.path', os.path.join(HOME_DIR, 'grampsdb'))
+register('database.host', '')
+register('database.port', '')
+
+register('export.proxy-order',
+         [["privacy", 0],
+          ["living", 0],
+          ["person", 0],
+          ["note", 0],
+          ["reference", 0]]
+        )
 
 register('geography.center-lon', 0.0)
 register('geography.lock', False)
@@ -171,62 +185,25 @@ register('geography.show_cross', False)
 register('geography.path', "")
 register('geography.use-keypad', True)
 
-register('interface.address-height', 450)
-register('interface.address-width', 650)
-register('interface.attribute-height', 350)
-register('interface.attribute-width', 600)
-register('interface.child-ref-height', 450)
-register('interface.child-ref-width', 600)
-register('interface.citation-height', 450)
-register('interface.citation-sel-height', 450)
-register('interface.citation-sel-width', 600)
-register('interface.citation-width', 600)
-register('interface.clipboard-height', 300)
-register('interface.clipboard-width', 300)
+# note that other calls to "register" are done in realtime (when
+# needed), for instance to four 'interface.clipboard' variables --
+# so do a recursive grep for "setup_configs" to see all the (base) names
 register('interface.dont-ask', False)
 register('interface.view-categories',
-         ["Dashboard", "People", "Relationships", "Families", 
+         ["Dashboard", "People", "Relationships", "Families",
           "Ancestry", "Events", "Places", "Geography", "Sources",
           "Citations", "Repositories", "Media", "Notes"])
-register('interface.edit-filter-width', 500)
-register('interface.edit-filter-height', 420)
-register('interface.edit-rule-width', 600)
-register('interface.edit-rule-height', 450)
-register('interface.event-height', 450)
-register('interface.event-ref-height', 450)
-register('interface.event-ref-width', 600)
-register('interface.event-sel-height', 450)
-register('interface.event-sel-width', 600)
-register('interface.event-width', 600)
-register('interface.family-height', 500)
-register('interface.family-sel-height', 450)
-register('interface.family-sel-width', 600)
-register('interface.family-width', 700)
 register('interface.filter', False)
-register('interface.filter-editor-width', 400)
-register('interface.filter-editor-height', 350)
 register('interface.fullscreen', False)
 register('interface.grampletbar-close', False)
-register('interface.height', 500)
 register('interface.ignore-gexiv2', False)
+register('interface.ignore-pil', False)
 register('interface.ignore-osmgpsmap', False)
-register('interface.lds-height', 450)
-register('interface.lds-width', 600)
-register('interface.location-height', 250)
-register('interface.location-width', 600)
+register('interface.main-window-height', 500)
+register('interface.main-window-horiz-position', 15)
+register('interface.main-window-vert-position', 10)
+register('interface.main-window-width', 775)
 register('interface.mapservice', 'OpenStreetMap')
-register('interface.media-height', 450)
-register('interface.media-ref-height', 450)
-register('interface.media-ref-width', 600)
-register('interface.media-sel-height', 450)
-register('interface.media-sel-width', 600)
-register('interface.media-width', 650)
-register('interface.name-height', 350)
-register('interface.name-width', 600)
-register('interface.note-height', 500)
-register('interface.note-sel-height', 450)
-register('interface.note-sel-width', 600)
-register('interface.note-width', 700)
 register('interface.open-with-default-viewer', False)
 register('interface.pedview-layout', 0)
 register('interface.pedview-show-images', True)
@@ -234,40 +211,13 @@ register('interface.pedview-show-marriage', False)
 register('interface.pedview-tree-size', 5)
 register('interface.pedview-tree-direction', 2)
 register('interface.pedview-show-unknown-people', False)
-register('interface.person-height', 550)
-register('interface.person-ref-height', 350)
-register('interface.person-ref-width', 600)
-register('interface.person-sel-height', 450)
-register('interface.person-sel-width', 600)
-register('interface.person-width', 750)
-register('interface.place-height', 450)
 register('interface.place-name-height', 100)
 register('interface.place-name-width', 450)
-register('interface.place-ref-height', 450)
-register('interface.place-ref-width', 600)
-register('interface.place-sel-height', 450)
-register('interface.place-sel-width', 600)
-register('interface.place-width', 650)
-register('interface.repo-height', 450)
-register('interface.repo-ref-height', 450)
-register('interface.repo-ref-width', 600)
-register('interface.repo-sel-height', 450)
-register('interface.repo-sel-width', 600)
-register('interface.repo-width', 650)
 register('interface.sidebar-text', True)
 register('interface.size-checked', False)
-register('interface.source-height', 450)
-register('interface.source-ref-height', 450)
-register('interface.source-ref-width', 600)
-register('interface.source-sel-height', 450)
-register('interface.source-sel-width', 600)
-register('interface.source-width', 600)
 register('interface.statusbar', 1)
 register('interface.toolbar-on', True)
-register('interface.url-height', 150)
-register('interface.url-width', 600)
 register('interface.view', True)
-register('interface.width', 775)
 register('interface.surname-box-height', 150)
 register('interface.treemodel-cache-size', 1000)
 
@@ -276,10 +226,13 @@ register('paths.recent-file', '')
 register('paths.recent-import-dir', '')
 register('paths.report-directory', USER_HOME)
 register('paths.website-directory', USER_HOME)
+register('paths.website-cms-uri', '')
+register('paths.website-cal-uri', '')
 register('paths.quick-backup-directory', USER_HOME)
-register('paths.quick-backup-filename', 
+register('paths.quick-backup-filename',
          "%(filename)s_%(year)d-%(month)02d-%(day)02d.%(extension)s")
 
+register('preferences.quick-backup-include-mode', False)
 register('preferences.date-format', 0)
 register('preferences.calendar-format-report', 0)
 register('preferences.cprefix', 'C%04d')
@@ -294,11 +247,8 @@ register('preferences.hide-ep-msg', False)
 register('preferences.invalid-date-format', "<b>%s</b>")
 register('preferences.iprefix', 'I%04d')
 register('preferences.name-format', 1)
+register('preferences.place-format', 0)
 register('preferences.place-auto', True)
-register('preferences.place-number', False)
-register('preferences.place-reverse', False)
-register('preferences.place-restrict', 0)
-register('preferences.place-lang', '')
 register('preferences.patronimic-surname', False)
 register('preferences.no-given-text', "[%s]" % _("Missing Given Name"))
 register('preferences.no-record-text', "[%s]" % _("Missing Record"))
@@ -309,9 +259,9 @@ register('preferences.oprefix', 'O%04d')
 register('preferences.paper-metric', 0)
 register('preferences.paper-preference', 'Letter')
 register('preferences.pprefix', 'P%04d')
-register('preferences.private-given-text', "[%s]" % _("Living"))
+register('preferences.private-given-text', "%s" % _T_("[Living]"))
 register('preferences.private-record-text', "[%s]" % _("Private Record"))
-register('preferences.private-surname-text', "[%s]" % _("Living"))
+register('preferences.private-surname-text', "%s" % _T_("[Living]"))
 register('preferences.rprefix', 'R%04d')
 register('preferences.sprefix', 'S%04d')
 register('preferences.use-last-view', False)
@@ -319,22 +269,25 @@ register('preferences.last-view', '')
 register('preferences.last-views', [])
 register('preferences.family-relation-type', 3) # UNKNOWN
 register('preferences.age-display-precision', 1)
-register('preferences.color-gender-male-alive', '#b8cee6')
-register('preferences.color-gender-male-death', '#b8cee6')
-register('preferences.color-gender-female-alive', '#feccf0')
-register('preferences.color-gender-female-death', '#feccf0')
-register('preferences.color-gender-unknown-alive', '#f3dbb6')
-register('preferences.color-gender-unknown-death', '#f3dbb6')
-#register('preferences.color-gender-other-alive', '#fcaf3e')
-#register('preferences.color-gender-other-death', '#fcaf3e')
-register('preferences.bordercolor-gender-male-alive', '#1f4986')
-register('preferences.bordercolor-gender-male-death', '#000000')
-register('preferences.bordercolor-gender-female-alive', '#861f69')
-register('preferences.bordercolor-gender-female-death', '#000000')
-register('preferences.bordercolor-gender-unknown-alive', '#8e5801')
-register('preferences.bordercolor-gender-unknown-death', '#000000')
-#register('preferences.bordercolor-gender-other-alive', '#f57900')
-#register('preferences.bordercolor-gender-other-death', '#000000')
+
+register('colors.scheme', 0)
+register('colors.male-alive', ['#b8cee6', '#1f344a'])
+register('colors.male-dead', ['#b8cee6', '#2d3039'])
+register('colors.female-alive', ['#feccf0', '#62242D'])
+register('colors.female-dead', ['#feccf0', '#3a292b'])
+register('colors.unknown-alive', ['#f3dbb6', '#75507B'])
+register('colors.unknown-dead', ['#f3dbb6', '#35103b'])
+register('colors.family', ['#eeeeee', '#454545'])
+register('colors.family-divorced', ['#ffdede', '#5c3636'])
+register('colors.home-person', ['#bbe68a', '#304918'])
+register('colors.border-male-alive', ['#1f4986', '#171d26'])
+register('colors.border-male-dead', ['#000000', '#000000'])
+register('colors.border-female-alive', ['#861f69', '#261111'])
+register('colors.border-female-dead', ['#000000', '#000000'])
+register('colors.border-unknown-alive', ['#8e5801', '#8e5801'])
+register('colors.border-unknown-dead', ['#000000', '#000000'])
+register('colors.border-family', ['#cccccc', '#252525'])
+register('colors.border-family-divorced', ['#ff7373', '#720b0b'])
 
 register('researcher.researcher-addr', '')
 register('researcher.researcher-locality', '')
@@ -349,6 +302,9 @@ register('researcher.researcher-state', '')
 register('plugin.hiddenplugins', [])
 register('plugin.addonplugins', [])
 
+if __debug__: # enable a simple CLI test to see if the datestrings exist
+    register('test.january', _("localized lexeme inflections||January"))
+
 #---------------------------------------------------------------
 #
 # Upgrade Conversions go here.
@@ -363,9 +319,33 @@ if not os.path.exists(CONFIGMAN.filename):
         # read it in old style:
         logging.warning("Importing old key file 'keys.ini'...")
         CONFIGMAN.load(os.path.join(HOME_DIR, "keys.ini"),
-                            oldstyle=True)
+                       oldstyle=True)
         logging.warning("Done importing old key file 'keys.ini'")
     # other version upgrades here...
+    # check previous version of gramps:
+    fullpath, filename = os.path.split(CONFIGMAN.filename)
+    fullpath, previous = os.path.split(fullpath)
+    match = re.match('gramps(\d*)', previous)
+    if match:
+        # cycle back looking for previous versions of gramps
+        for i in range(1, 20): # check back 2 gramps versions
+            # -----------------------------------------
+            # TODO: Assumes minor version is a decimal, not semantic versioning
+            #       Uses ordering ... 4.9, 5.0, 5.1, ...
+            #       Not ... 4.9, 4.10, 4.11, 5.0, 5.1, ...
+            # If not true, need to add a different method to auto upgrade.
+            # Perhaps addings specific list of versions to check
+            # -----------------------------------------
+            digits = str(int(match.groups()[0]) - i)
+            previous_grampsini = os.path.join(fullpath, "gramps" + digits,
+                                              filename)
+            if os.path.exists(previous_grampsini):
+                logging.warning("Importing old config file '%s'...",
+                                previous_grampsini)
+                CONFIGMAN.load(previous_grampsini)
+                logging.warning("Done importing old config file '%s'",
+                                previous_grampsini)
+                break
 
 #---------------------------------------------------------------
 #
