@@ -3,6 +3,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2004-2006  Donald N. Allingham
+# Copyright (C) 2017       Paul Franklin
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -42,11 +43,11 @@ log = logging.getLogger(".DateParser")
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from ..lib.date import Date, DateError, Today
-from . import _grampslocale
+from ..const import GRAMPS_LOCALE as glocale
 from ..utils.grampslocale import GrampsLocale
 from ._datestrings import DateStrings
 
@@ -115,7 +116,7 @@ def french_valid(date_tuple):
     valid = True
     # year 1 starts on 22.9.1792
     if date_tuple[2] < 1:
-        valid = False       
+        valid = False
     return valid
 
 def _build_prefix_table(month_to_int, month_variants):
@@ -186,16 +187,13 @@ def _generate_variants(months):
 # DateParser class
 #
 #-------------------------------------------------------------------------
-class DateParser(object):
+class DateParser:
     """
     Convert a text string into a :class:`.Date` object. If the date cannot be
     converted, the text string is assigned.
     """
 
-    _locale = GrampsLocale(lang='en', languages='en')
-    
-    fmt = _grampslocale.tformat
-    _fmt_parse = re.compile(".*%(\S).*%(\S).*%(\S).*")
+    _dhformat_parse = re.compile(".*%(\S).*%(\S).*%(\S).*")
 
     # RFC-2822 only uses capitalized English abbreviated names, no locales.
     _rfc_days = ('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat')
@@ -235,7 +233,7 @@ class DateParser(object):
         #alternative spelling
         "cheshvan": 2,   "adar sheni":  7, "iyar"    : 9,
         #GEDCOM months
-        "tsh" : 1, "csh": 5, "ksl": 3, "tvt": 4, "shv": 5, "adr": 6, 
+        "tsh" : 1, "csh": 5, "ksl": 3, "tvt": 4, "shv": 5, "adr": 6,
         "ads" : 7, "nsn": 8, "iyr": 9, "svn":10, "tmz":11, "aav":12,
         "ell":13,
         }
@@ -286,10 +284,10 @@ class DateParser(object):
     newyear_to_int = {
         "jan1":  Date.NEWYEAR_JAN1,
         "mar1":  Date.NEWYEAR_MAR1,
-        "mar25": Date.NEWYEAR_MAR25, 
+        "mar25": Date.NEWYEAR_MAR25,
         "sep1" : Date.NEWYEAR_SEP1,
         }
-    
+
     quality_to_int = {
         'estimated'  : Date.QUAL_ESTIMATED,
         'est.'       : Date.QUAL_ESTIMATED,
@@ -306,7 +304,7 @@ class DateParser(object):
         # see init_strings, so there is no need to override this if you have no aliases
         # for "today".
         # We also secretly support "$T" like in some reports.
-    
+
     _langs = set()
     def __init_prefix_tables(self):
         lang = self._locale.lang
@@ -315,11 +313,11 @@ class DateParser(object):
             return
         else:
             DateParser._langs.add(lang)
-        ds = DateStrings(self._locale)
+        ds = self._ds = DateStrings(self._locale)
         log.debug("Begin building parser prefix tables for {}".format(lang))
-        _build_prefix_table(DateParser.month_to_int, 
+        _build_prefix_table(DateParser.month_to_int,
             _generate_variants(
-                    zip(ds.long_months, ds.short_months, 
+                    zip(ds.long_months, ds.short_months,
                         ds.swedish_SV, ds.alt_long_months)))
         _build_prefix_table(DateParser.hebrew_to_int,
             _generate_variants(zip(ds.hebrew)))
@@ -332,7 +330,21 @@ class DateParser(object):
         _build_prefix_table(DateParser.calendar_to_int,
                 _generate_variants(zip(ds.calendar)))
 
-    def __init__(self):
+    def __init__(self, plocale=None):
+        """
+        :param plocale: allow correct date format to be loaded and parsed
+        :type plocale: a :class:`.GrampsLocale` instance
+        """
+        from ._datehandler import locale_tformat # circular import if above
+        if plocale:
+            self._locale = plocale
+        elif not hasattr(self, '_locale'):
+            self._locale = glocale
+        if self._locale.calendar in locale_tformat:
+            self.dhformat = locale_tformat[self._locale.calendar] # date format
+        else:
+            self.dhformat = locale_tformat['en_GB'] # something is required
+        self.dhformat_changed() # Allow overriding so a subclass can modify it
         self.init_strings()
         self.parser = {
             Date.CAL_GREGORIAN : self._parse_gregorian,
@@ -344,16 +356,24 @@ class DateParser(object):
             Date.CAL_SWEDISH   : self._parse_swedish,
             }
 
-        match = self._fmt_parse.match(self.fmt.lower())
+        match = self._dhformat_parse.match(self.dhformat.lower())
         if match:
-            self.dmy = (match.groups() == ('d', 'm', 'y') or \
-                       match.groups() == ('d', 'b', 'y'))
+            self._ddmy = match.groups() == ('a', 'e', 'b', 'y') # Icelandic
+            self.dmy = (match.groups() == ('d', 'm', 'y') or
+                        match.groups() == ('e', 'm', 'y') or # Bulgarian
+                        match.groups() == ('d', 'b', 'y') or
+                        match.groups() == ('a', 'e', 'b', 'y'))
             self.ymd = (match.groups() == ('y', 'm', 'd') or \
                        match.groups() == ('y', 'b', 'd'))
             # note ('m','d','y') is valid -- in which case both will be False
         else:
             self.dmy = True
             self.ymd = False
+            self._ddmy = False
+
+    def dhformat_changed(self):
+        """ Allow overriding so a subclass can modify it """
+        pass
 
     def re_longest_first(self, keys):
         """
@@ -367,14 +387,14 @@ class DateParser(object):
     def init_strings(self):
         """
         This method compiles regular expression strings for matching dates.
-        
+
         Most of the re's in most languages can stay as is. span and range
         most likely will need to change. Whatever change is done, this method
         may be called first as DateParser.init_strings(self) so that the
-        invariant expresions don't need to be repeteadly coded. All differences
+        invariant expresions don't need to be repeatedly coded. All differences
         can be coded after DateParser.init_strings(self) call, that way they
         override stuff from this method.
-        
+
         .. seealso:: :class:`.DateParserRU` as an example.
         """
         _ = self._locale.translation.gettext
@@ -419,7 +439,7 @@ class DateParser(object):
 
         self._qual     = re.compile("(.* ?)%s\s+(.+)" % self._qual_str,
                                     re.IGNORECASE)
-        
+
         self._span     = re.compile("(from)\s+(?P<start>.+)\s+to\s+(?P<stop>.+)",
                                     re.IGNORECASE)
         self._range    = re.compile("(bet|bet.|between)\s+(?P<start>.+)\s+and\s+(?P<stop>.+)",
@@ -429,8 +449,9 @@ class DateParser(object):
         self._modifier_after = re.compile('(.*)\s+%s' % self._mod_after_str,
                                           re.IGNORECASE)
         self._abt2     = re.compile('<(.*)>', re.IGNORECASE)
-        self._text     = re.compile('%s\.?\s+(\d+)?\s*,?\s*((\d+)(/\d+)?)?\s*$' % self._mon_str,
-                                    re.IGNORECASE)
+        self._text     = re.compile('%s\.?(\s+\d+)?\s*,?\s+((\d+)(/\d+)?)?\s*$'
+                                        % self._mon_str, re.IGNORECASE)
+        # this next RE has the (possibly-slashed) year at the string's end
         self._text2    = re.compile('(\d+)?\s+?%s\.?\s*((\d+)(/\d+)?)?\s*$' % self._mon_str,
                                     re.IGNORECASE)
         self._jtext    = re.compile('%s\s+(\d+)?\s*,?\s*((\d+)(/\d+)?)?\s*$' % self._jmon_str,
@@ -456,7 +477,7 @@ class DateParser(object):
         self._numeric  = re.compile("((\d+)[/\.]\s*)?((\d+)[/\.]\s*)?(\d+)\s*$")
         self._iso      = re.compile("(\d+)(/(\d+))?-(\d+)-(\d+)\s*$")
         self._isotimestamp = re.compile("^\s*?(\d{4})([01]\d)([0123]\d)(?:(?:[012]\d[0-5]\d[0-5]\d)|(?:\s+[012]\d:[0-5]\d(?::[0-5]\d)?))?\s*?$")
-        self._rfc      = re.compile("(%s,)?\s+(\d|\d\d)\s+%s\s+(\d+)\s+\d\d:\d\d(:\d\d)?\s+(\+|-)\d\d\d\d" 
+        self._rfc      = re.compile("(%s,)?\s+(\d|\d\d)\s+%s\s+(\d+)\s+\d\d:\d\d(:\d\d)?\s+(\+|-)\d\d\d\d"
                                     % (self._rfc_day_str, self._rfc_mon_str))
         self._today = re.compile("^\s*%s\s*$" % self._today_str, re.IGNORECASE)
 
@@ -498,10 +519,10 @@ class DateParser(object):
         return self._parse_calendar(text, self._stext, self._stext2,
                                     self.swedish_to_int,swedish_valid)
 
-                             
+
     def _parse_calendar(self, text, regex1, regex2, mmap, check=None):
         match = regex1.match(text.lower())
-        if match:
+        if match: # user typed in 'month-name day year' or 'month-name year'
             groups = match.groups()
             if groups[0] is None:
                 m = 0
@@ -514,19 +535,21 @@ class DateParser(object):
                 s = False
             else:
                 d = self._get_int(groups[1])
-                if groups[4] is not None: # slash year "/80"
+                if groups[4] is not None:
                     y = int(groups[3]) + 1 # fullyear + 1
-                    s = True
-                else: # regular, non-slash date
+                    s = True # slash year
+                else: # regular year
                     y = int(groups[3])
                     s = False
             value = (d, m, y, s)
-            if check and not check((d, m, y)):
+            if s and julian_valid(value): # slash year
+                pass
+            elif check and not check((d, m, y)):
                 value = Date.EMPTY
             return value
 
         match = regex2.match(text.lower())
-        if match:
+        if match: # user typed in day month-name year or year month-name day
             groups = match.groups()
             if self.ymd:
                 if groups[3] is None:
@@ -538,10 +561,10 @@ class DateParser(object):
                     y = None
                     s = False
                 else:
-                    if groups[2] is not None: # slash year digit
+                    if groups[2] is not None:
                         y = int(groups[1]) + 1 # fullyear + 1
-                        s = True
-                    else: # regular, non-slash year
+                        s = True # slash year
+                    else: # regular year
                         y = int(groups[1])
                         s = False
             else:
@@ -554,19 +577,19 @@ class DateParser(object):
                     y = None
                     s = False
                 else:
-                    if groups[4] is not None: # slash year digit
+                    if groups[4] is not None:
                         y = int(groups[3]) + 1 # fullyear + 1
-                        s = True
-                    else: # regular, non-slash year
+                        s = True # slash year
+                    else: # regular year
                         y = int(groups[3])
                         s = False
             value = (d, m, y, s)
             if check and not check((d, m, y)):
                 value = Date.EMPTY
             return value
-        
+
         return Date.EMPTY
-    
+
     def _parse_subdate(self, text, subparser=None, cal=None):
         """
         Convert only the date portion of a date.
@@ -591,18 +614,18 @@ class DateParser(object):
         value = subparser(text)
         if value != Date.EMPTY:
             return value
+
         match = self._iso.match(text)
         if match:
             groups = match.groups()
             y = self._get_int(groups[0])
             m = self._get_int(groups[3])
             d = self._get_int(groups[4])
-            if check and not check((d, m, y)):
-                return Date.EMPTY
-            if groups[2]: # slash year digit
-                return (d, m, y + 1, True)
-            else:
+            if groups[2] and julian_valid((d, m, y + 1)):
+                return (d, m, y + 1, True) # slash year
+            if check is None or check((d, m, y)):
                 return (d, m, y, False)
+            return Date.EMPTY
 
         # Database datetime format, used in ex. MSSQL
         # YYYYMMDD HH:MM:SS or YYYYMMDD or YYYYMMDDHHMMSS
@@ -633,6 +656,8 @@ class DateParser(object):
             groups = match.groups()
             if groups == (None, None, None, None, None):
                 return Date.EMPTY
+            if self._ddmy: # Icelandic
+                groups = groups[1:] # ignore the day of the week at the start
             if self.ymd:
                 # '1789' and ymd: incomplete date
                 if groups[1] is None:
@@ -647,6 +672,15 @@ class DateParser(object):
                     y = self._get_int(groups[1])
                     m = self._get_int(groups[3])
                     d = self._get_int(groups[4])
+                if m > 12: # maybe a slash year, not a month (1722/3 is March)
+                    if y % 100 == 99:
+                        modyear = (y + 1) % 1000
+                    elif y % 10 == 9:
+                        modyear = (y + 1) % 100
+                    else:
+                        modyear = (y + 1) % 10
+                    if m == modyear:
+                        return (0, 0, y + 1, True) # slash year
             else:
                 y = self._get_int(groups[4])
                 if self.dmy:
@@ -659,6 +693,15 @@ class DateParser(object):
                 else:
                     m = self._get_int(groups[1])
                     d = self._get_int(groups[3])
+                if m > 12: # maybe a slash year, not a month
+                    if m % 100 == 99:
+                        modyear = (m + 1) % 1000
+                    elif m % 10 == 9:
+                        modyear = (m + 1) % 100
+                    else:
+                        modyear = (m + 1) % 10
+                    if y == modyear:
+                        return (0, 0, m + 1, True) # slash year
             value = (d, m, y, False)
             if check and not check((d, m, y)):
                 value = Date.EMPTY
@@ -676,7 +719,7 @@ class DateParser(object):
     def match_calendar(self, text, cal):
         """
         Try parsing calendar.
-        
+
         Return calendar index and the text with calendar removed.
         """
         match = self._cal.match(text)
@@ -688,7 +731,7 @@ class DateParser(object):
     def match_calendar_newyear(self, text, cal, newyear):
         """
         Try parsing calendar and newyear code.
-        
+
         Return newyear index and the text with calendar removed.
         """
         match = self._calny.match(text)
@@ -707,7 +750,7 @@ class DateParser(object):
     def match_newyear(self, text, newyear):
         """
         Try parsing calendar and newyear code.
-        
+
         Return newyear index and the text with calendar removed.
         """
         match = self._ny.match(text)
@@ -724,7 +767,7 @@ class DateParser(object):
     def match_quality(self, text, qual):
         """
         Try matching quality.
-        
+
         Return quality index and the text with quality removed.
         """
         match = self._qual.match(text)
@@ -736,7 +779,7 @@ class DateParser(object):
     def match_span(self, text, cal, ny, qual, date):
         """
         Try matching span date.
-        
+
         On success, set the date and return 1. On failure return 0.
         """
         match = self._span.match(text)
@@ -763,7 +806,7 @@ class DateParser(object):
     def match_range(self, text, cal, ny, qual, date):
         """
         Try matching range date.
-        
+
         On success, set the date and return 1. On failure return 0.
         """
         match = self._range.match(text)
@@ -782,7 +825,7 @@ class DateParser(object):
                 return 0
             if bc2:
                 stop = self.invert_year(stop)
-            
+
             date.set(qual, Date.MOD_RANGE, cal, start + stop, newyear=ny)
             return 1
         return 0
@@ -790,7 +833,7 @@ class DateParser(object):
     def match_bce(self, text):
         """
         Try matching BCE qualifier.
-        
+
         Return BCE (True/False) and the text with matched part removed.
         """
         match = self._bce_re.match(text)
@@ -807,7 +850,7 @@ class DateParser(object):
     def match_modifier(self, text, cal, ny, qual, bc, date):
         """
         Try matching date with modifier.
-        
+
         On success, set the date and return 1. On failure return 0.
         """
         # modifiers before the date
@@ -864,7 +907,7 @@ class DateParser(object):
         qual = Date.QUAL_NONE
         cal  = Date.CAL_GREGORIAN
         newyear = Date.NEWYEAR_JAN1
-        
+
         (text, cal, newyear) = self.match_calendar_newyear(text, cal, newyear)
         (text, newyear) = self.match_newyear(text, newyear)
         (text, cal) = self.match_calendar(text, cal)
@@ -884,8 +927,6 @@ class DateParser(object):
             if subdate == Date.EMPTY and text != "":
                 date.set_as_text(text)
                 return
-            #else:
-            #    print 'valid subdate', text, subdate
         except:
             date.set_as_text(text)
             return
@@ -897,7 +938,7 @@ class DateParser(object):
 
     def invert_year(self, subdate):
         return (subdate[0], subdate[1], -subdate[2], subdate[3])
-    
+
     def parse(self, text):
         """
         Parses the text, returning a :class:`.Date` object.
