@@ -5,6 +5,7 @@
 # Copyright (C) 2010       Michiel D. Nauta
 # Copyright (C) 2011       Tim G L Lyons
 # Copyright (C) 2013       Doug Blank <doug.blank@gmail.com>
+# Copyright (C) 2017       Nick Hall
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +28,7 @@ Place object for Gramps.
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from .primaryobj import PrimaryObject
@@ -40,7 +41,8 @@ from .mediabase import MediaBase
 from .urlbase import UrlBase
 from .tagbase import TagBase
 from .location import Location
-from .handle import Handle
+from ..const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
@@ -53,7 +55,7 @@ class Place(CitationBase, NoteBase, MediaBase, UrlBase, PrimaryObject):
     information (since place names can change with time), longitude, latitude,
     a collection of images and URLs, a note and a source.
     """
-    
+
     def __init__(self, source=None):
         """
         Create a new Place object, copying from the source if present.
@@ -90,9 +92,9 @@ class Place(CitationBase, NoteBase, MediaBase, UrlBase, PrimaryObject):
     def serialize(self):
         """
         Convert the data held in the Place to a Python tuple that
-        represents all the data elements. 
-        
-        This method is used to convert the object into a form that can easily 
+        represents all the data elements.
+
+        This method is used to convert the object into a form that can easily
         be saved to a database.
 
         These elements may be primitive Python types (string, integers),
@@ -106,7 +108,7 @@ class Place(CitationBase, NoteBase, MediaBase, UrlBase, PrimaryObject):
         :rtype: tuple
         """
         return (self.handle, self.gramps_id, self.title, self.long, self.lat,
-                [pr.serialize() for pr in self.placeref_list], 
+                [pr.serialize() for pr in self.placeref_list],
                 self.name.serialize(),
                 [an.serialize() for an in self.alt_names],
                 self.place_type.serialize(), self.code,
@@ -117,72 +119,69 @@ class Place(CitationBase, NoteBase, MediaBase, UrlBase, PrimaryObject):
                 NoteBase.serialize(self),
                 self.change, TagBase.serialize(self), self.private)
 
-    def to_struct(self):
+    @classmethod
+    def get_schema(cls):
         """
-        Convert the data held in this object to a structure (eg,
-        struct) that represents all the data elements.
-        
-        This method is used to recursively convert the object into a
-        self-documenting form that can easily be used for various
-        purposes, including diffs and queries.
+        Returns the JSON Schema for this class.
 
-        These structures may be primitive Python types (string,
-        integer, boolean, etc.) or complex Python types (lists,
-        tuples, or dicts). If the return type is a dict, then the keys
-        of the dict match the fieldname of the object. If the return
-        struct (or value of a dict key) is a list, then it is a list
-        of structs. Otherwise, the struct is just the value of the
-        attribute.
-
-        :returns: Returns a struct containing the data of the object.
+        :returns: Returns a dict containing the schema.
         :rtype: dict
         """
-        return {"_class": "Place",
-                "handle": Handle("Place", self.handle), 
-                "gramps_id": self.gramps_id, 
-                "title": self.title, 
-                "long": self.long, 
-                "lat": self.lat,
-                "placeref_list": [pr.to_struct() for pr in self.placeref_list],
-                "name": self.name.to_struct(),
-                "alt_names": [an.to_struct() for an in self.alt_names],
-                "place_type": self.place_type.to_struct(), 
-                "code": self.code, 
-                "alt_loc": [al.to_struct() for al in self.alt_loc],
-                "urls": UrlBase.to_struct(self),
-                "media_list": MediaBase.to_struct(self),
-                "citation_list": CitationBase.to_struct(self),
-                "note_list": NoteBase.to_struct(self),
-                "change": self.change, 
-                "tag_list": TagBase.to_struct(self),
-                "private": self.private}
-
-    @classmethod
-    def from_struct(cls, struct):
-        """
-        Given a struct data representation, return a serialized object.
-
-        :returns: Returns a serialized object
-        """
-        default = Place()
-        return (Handle.from_struct(struct.get("handle", default.handle)),
-                struct.get("gramps_id", default.gramps_id),
-                struct.get("title", default.title),
-                struct.get("long", default.long),
-                struct.get("lat", default.lat),
-                [PlaceRef.from_struct(pr) for pr in struct.get("placeref_list", default.placeref_list)],
-                PlaceName.from_struct(struct.get("name", {})),
-                [PlaceName.from_struct(an) for an in struct.get("alt_names", default.alt_names)],
-                PlaceType.from_struct(struct.get("place_type", {})), 
-                struct.get("code", default.code),
-                [Location.from_struct(al) for al in struct.get("alt_loc", default.alt_loc)],
-                UrlBase.from_struct(struct.get("urls", default.urls)),
-                MediaBase.from_struct(struct.get("media_list", default.media_list)),
-                CitationBase.from_struct(struct.get("citation_list", default.citation_list)),
-                NoteBase.from_struct(struct.get("note_list", default.note_list)),
-                struct.get("change", default.change), 
-                TagBase.from_struct(struct.get("tag_list", default.tag_list)),
-                struct.get("private", default.private))
+        from .url import Url
+        from .mediaref import MediaRef
+        return {
+            "type": "object",
+            "title": _("Place"),
+            "properties": {
+                "_class": {"enum": [cls.__name__]},
+                "handle": {"type": "string",
+                           "maxLength": 50,
+                           "title": _("Handle")},
+                "gramps_id": {"type": "string",
+                              "title": _("Gramps ID")},
+                "title": {"type": "string",
+                          "title": _("Title")},
+                "long": {"type": "string",
+                         "title": _("Longitude")},
+                "lat": {"type": "string",
+                        "title": _("Latitude")},
+                "placeref_list": {"type": "array",
+                                  "items": PlaceRef.get_schema(),
+                                  "title": _("Places")},
+                "name": PlaceName.get_schema(),
+                "alt_names": {"type": "array",
+                              "items": PlaceName.get_schema(),
+                              "title": _("Alternate Names")},
+                "place_type": PlaceType.get_schema(),
+                "code": {"type": "string",
+                         "title": _("Code")},
+                "alt_loc": {"type": "array",
+                            "items": Location.get_schema(),
+                            "title": _("Alternate Locations")},
+                "urls": {"type": "array",
+                         "items": Url.get_schema(),
+                         "title": _("URLs")},
+                "media_list": {"type": "array",
+                               "items": MediaRef.get_schema(),
+                               "title": _("Media")},
+                "citation_list": {"type": "array",
+                                  "items": {"type": "string",
+                                            "maxLength": 50},
+                                  "title": _("Citations")},
+                "note_list": {"type": "array",
+                              "items": {"type": "string",
+                                        "maxLength": 50},
+                              "title": _("Notes")},
+                "change": {"type": "integer",
+                           "title": _("Last changed")},
+                "tag_list": {"type": "array",
+                             "items": {"type": "string",
+                                       "maxLength": 50},
+                             "title": _("Tags")},
+                "private": {"type": "boolean",
+                            "title": _("Private")}
+            }
+        }
 
     def unserialize(self, data):
         """
@@ -245,7 +244,7 @@ class Place(CitationBase, NoteBase, MediaBase, UrlBase, PrimaryObject):
         """
         Return the list of child secondary objects that may refer notes.
 
-        :returns: Returns the list of child secondary child objects that may 
+        :returns: Returns the list of child secondary child objects that may
                 refer notes.
         :rtype: list
         """
@@ -255,7 +254,7 @@ class Place(CitationBase, NoteBase, MediaBase, UrlBase, PrimaryObject):
         """
         Return the list of child objects which may, directly or through
         their children, reference primary objects.
-        
+
         :returns: Returns the list of objects referencing primary objects.
         :rtype: list
         """
@@ -265,7 +264,7 @@ class Place(CitationBase, NoteBase, MediaBase, UrlBase, PrimaryObject):
         """
         Return the list of (classname, handle) tuples for all directly
         referenced primary objects.
-        
+
         :returns: List of (classname, handle) tuples for referenced objects.
         :rtype: list
         """
@@ -454,14 +453,14 @@ class Place(CitationBase, NoteBase, MediaBase, UrlBase, PrimaryObject):
 
     def _has_handle_reference(self, classname, handle):
         """
-        Return True if the object has reference to a given handle of given 
+        Return True if the object has reference to a given handle of given
         primary object type.
-        
+
         :param classname: The name of the primary object class.
         :type classname: str
         :param handle: The handle to be checked.
         :type handle: str
-        :returns: Returns whether the object has reference to this handle of 
+        :returns: Returns whether the object has reference to this handle of
                 this object type.
         :rtype: bool
         """
@@ -519,8 +518,8 @@ class Place(CitationBase, NoteBase, MediaBase, UrlBase, PrimaryObject):
     def get_alternate_locations(self):
         """
         Return a list of alternate :class:`~.location.Location` objects the
-        present alternate information about the current Place. 
-        
+        present alternate information about the current Place.
+
         A Place can have more than one :class:`~.location.Location`, since names
         and jurisdictions can change over time for the same place.
 
@@ -577,9 +576,13 @@ class Place(CitationBase, NoteBase, MediaBase, UrlBase, PrimaryObject):
         :param acquisition: instance to merge
         :type acquisition: :class:'~.place.Place
         """
-        if acquisition.name and (acquisition.name not in self.alt_names):
-            self.alt_names.append(acquisition.name)
+        if acquisition.name.value:
+            if acquisition.name != self.name:
+                if acquisition.name not in self.alt_names:
+                    self.alt_names.append(acquisition.name)
 
         for addendum in acquisition.alt_names:
-            if addendum not in self.alt_names:
-                self.alt_names.append(addendum)
+            if addendum.value:
+                if addendum != self.name:
+                    if addendum not in self.alt_names:
+                        self.alt_names.append(addendum)
