@@ -43,33 +43,32 @@ from gi.repository import GLib
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS classes
+# Gramps classes
 #
 #-------------------------------------------------------------------------
 from ...utils import is_right_click, open_file_with_default_application
 from ...dbguielement import DbGUIElement
 from ...selectors import SelectorFactory
-from gramps.gen.constfunc import win, conv_to_unicode
-from gramps.gen.lib import MediaObject, MediaRef
+from gramps.gen.lib import Media, MediaRef
 from gramps.gen.db import DbTxn
 from gramps.gen.utils.file import (media_path_full, media_path, relative_path,
                                    create_checksum)
-from ...thumbnails import get_thumbnail_image
+from gramps.gen.utils.thumbnails import get_thumbnail_image
 from gramps.gen.errors import WindowActiveError
 from gramps.gen.mime import get_type, is_valid_type
 from ...ddtargets import DdTargets
 from .buttontab import ButtonTab
 from gramps.gen.const import THUMBSCALE
 from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
-#-------------------------------------------------------------------------
-#
-# 
-#
-#-------------------------------------------------------------------------
-def make_launcher(path):
-    return lambda x: open_file_with_default_application(path)
+_ = glocale.translation.sgettext
 
+#-------------------------------------------------------------------------
+#
+#
+#
+#-------------------------------------------------------------------------
+def make_launcher(path, uistate):
+    return lambda x: open_file_with_default_application(path, uistate)
 #-------------------------------------------------------------------------
 #
 # GalleryTab
@@ -86,7 +85,7 @@ class GalleryTab(ButtonTab, DbGUIElement):
         DbGUIElement.__init__(self, dbstate.db)
         self.track_ref_for_deletion("iconlist")
         self.media_list = media_list
-        self.callman.register_handles({'media': [mref.ref for mref 
+        self.callman.register_handles({'media': [mref.ref for mref
                                                           in self.media_list]})
         self.update = update
 
@@ -94,21 +93,21 @@ class GalleryTab(ButtonTab, DbGUIElement):
 
         self.rebuild()
         self.show_all()
-    
+
     def _connect_db_signals(self):
         """
         Implement base class DbGUIElement method
         """
         #note: media-rebuild closes the editors, so no need to connect to it
         self.callman.register_callbacks(
-           {'media-delete': self.media_delete,  # delete a mediaobj we track
-            'media-update': self.media_update,  # change a mediaobj we track
+           {'media-delete': self.media_delete,  # delete a media we track
+            'media-update': self.media_update,  # change a media we track
            })
         self.callman.connect_all(keys=['media'])
 
     def double_click(self, obj, event):
         """
-        Handle the button press event: double click or right click on iconlist. 
+        Handle the button press event: double click or right click on iconlist.
         If the double click occurs, the Edit button handler is called.
         """
         if event.type == Gdk.EventType._2BUTTON_PRESS and event.button == 1:
@@ -125,55 +124,49 @@ class GalleryTab(ButtonTab, DbGUIElement):
 
     def right_click(self, obj, event):
         itemlist = [
-            (True, True, 'list-add', self.add_button_clicked),
-            (True, False, _('Share'), self.share_button_clicked),
-            (False,True, 'gtk-edit', self.edit_button_clicked),
-            (True, True, 'list-remove', self.del_button_clicked),
+            (True, _('_Add'), self.add_button_clicked),
+            (True, _('Share'), self.share_button_clicked),
+            (False, _('_Edit'), self.edit_button_clicked),
+            (True, _('_Remove'), self.del_button_clicked),
             ]
 
         self.menu = Gtk.Menu()
+        self.menu.set_reserve_toggle_size(False)
 
-        ref_obj = self.dbstate.db.get_object_from_handle(obj.ref)
+        ref_obj = self.dbstate.db.get_media_from_handle(obj.ref)
         media_path = media_path_full(self.dbstate.db, ref_obj.get_path())
         if media_path:
-            item = Gtk.ImageMenuItem(_('View'))
-            img = Gtk.Image()
-            img.set_from_icon_name("gramps-viewmedia", Gtk.IconSize.MENU)
-            item.set_image(img)
-            item.connect('activate', make_launcher(media_path))
+            # Translators: _View means "to look at this"
+            item = Gtk.MenuItem.new_with_mnemonic(_('verb:look at this|_View'))
+            item.connect('activate', make_launcher(media_path, self.uistate))
             item.show()
             self.menu.append(item)
             mfolder, mfile = os.path.split(media_path)
-            item = Gtk.MenuItem(label=_('Open Containing _Folder'))
-            item.connect('activate', make_launcher(mfolder))
+            item = Gtk.MenuItem.new_with_mnemonic(_('Open Containing _Folder'))
+            item.connect('activate', make_launcher(mfolder, self.uistate))
             item.show()
             self.menu.append(item)
             item = Gtk.SeparatorMenuItem()
             item.show()
             self.menu.append(item)
-        
-            item = Gtk.MenuItem(_('Make Active Media'))
+
+            item = Gtk.MenuItem.new_with_mnemonic(_('_Make Active Media'))
             item.connect('activate', lambda obj: self.uistate.set_active(ref_obj.handle, "Media"))
             item.show()
             self.menu.append(item)
             item = Gtk.SeparatorMenuItem()
             item.show()
             self.menu.append(item)
-        
-        for (needs_write_access, image, title, func) in itemlist:
-            if image:
-                item = Gtk.ImageMenuItem()
-                img = Gtk.Image.new_from_icon_name(title, Gtk.IconSize.MENU)
-                item.set_image(img)
-            else:
-                item = Gtk.MenuItem(label=title)
+
+        for (needs_write_access, title, func) in itemlist:
+            item = Gtk.MenuItem.new_with_mnemonic(title)
             item.connect('activate', func)
             if needs_write_access and self.dbstate.db.readonly:
                 item.set_sensitive(False)
             item.show()
             self.menu.append(item)
         self.menu.popup(None, None, None, None, event.button, event.time)
-        
+
     def get_icon_name(self):
         return 'gramps-media'
 
@@ -181,7 +174,7 @@ class GalleryTab(ButtonTab, DbGUIElement):
         return len(self.media_list)==0
 
     def _build_icon_model(self):
-        self.iconmodel = Gtk.ListStore(GdkPixbuf.Pixbuf, GObject.TYPE_STRING, 
+        self.iconmodel = Gtk.ListStore(GdkPixbuf.Pixbuf, GObject.TYPE_STRING,
                                       object)
         self.track_ref_for_deletion("iconmodel")
 
@@ -192,16 +185,16 @@ class GalleryTab(ButtonTab, DbGUIElement):
 
     def build_interface(self):
         """Setup the GUI.
-        
+
         It includes an IconView placed inside of a ScrolledWindow.
-        
+
         """
         # create the model used with the icon view
         self._build_icon_model()
 
         # pixels to pad the image
         padding = 6
-        
+
         # build the icon view
         self.iconlist.set_pixbuf_column(0)
         self.iconlist.set_item_width(int(THUMBSCALE) + padding * 2)
@@ -212,23 +205,23 @@ class GalleryTab(ButtonTab, DbGUIElement):
         text_renderer.set_property('alignment', Pango.Alignment.CENTER)
         self.iconlist.pack_end(text_renderer, True)
         self.iconlist.add_attribute(text_renderer, "text", 1)
-        
+
         # set basic properties of the icon view
         self.iconlist.set_margin(padding)
         self.iconlist.set_column_spacing(padding)
         self.iconlist.set_reorderable(True)
         self.iconlist.set_selection_mode(Gtk.SelectionMode.SINGLE)
-        
+
         # connect the signals
         self.__id_connect_sel = self.iconlist.connect('selection-changed', self._selection_changed)
         self.iconlist.connect('button_press_event', self.double_click)
         self.iconlist.connect('key_press_event', self.key_pressed)
         self._connect_icon_model()
-        
+
         # create the scrolled window
         scroll = Gtk.ScrolledWindow()
         scroll.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
-        
+
         # put everything together
         scroll.add(self.iconlist)
         self.pack_end(scroll, True, True, 0)
@@ -256,16 +249,17 @@ class GalleryTab(ButtonTab, DbGUIElement):
         self._build_icon_model()
         for ref in self.media_list:
             handle = ref.get_reference_handle()
-            obj = self.dbstate.db.get_object_from_handle(handle)
+            obj = self.dbstate.db.get_media_from_handle(handle)
             if obj is None :
                 #notify user of error
                 from ...dialog import RunDatabaseRepair
                 RunDatabaseRepair(
-                            _('Non existing media found in the Gallery'))
+                    _('Non existing media found in the Gallery'),
+                    parent=self.uistate.window)
             else :
                 pixbuf = get_thumbnail_image(
-                                media_path_full(self.dbstate.db, 
-                                                      obj.get_path()), 
+                                media_path_full(self.dbstate.db,
+                                                      obj.get_path()),
                                 obj.get_mime_type(),
                                 ref.get_rectangle())
                 self.iconmodel.append(row=[pixbuf, obj.get_description(), ref])
@@ -274,7 +268,7 @@ class GalleryTab(ButtonTab, DbGUIElement):
         self._selection_changed()
         if self.update:
             self.update()
-        
+
     def get_selected(self):
         node = self.iconlist.get_selected_items()
         if len(node) > 0:
@@ -285,8 +279,8 @@ class GalleryTab(ButtonTab, DbGUIElement):
     def add_button_clicked(self, obj):
         try:
             from .. import EditMediaRef
-            EditMediaRef(self.dbstate, self.uistate, self.track, 
-                         MediaObject(), MediaRef(),
+            EditMediaRef(self.dbstate, self.uistate, self.track,
+                         Media(), MediaRef(),
                          self.add_callback)
         except WindowActiveError:
             pass
@@ -318,12 +312,12 @@ class GalleryTab(ButtonTab, DbGUIElement):
 
     def share_button_clicked(self, obj):
         """
-        Function called when the Share button is clicked. 
-        
+        Function called when the Share button is clicked.
+
         This function should be overridden by the derived class.
-        
+
         """
-        SelectObject = SelectorFactory('MediaObject')
+        SelectObject = SelectorFactory('Media')
 
         sel = SelectObject(self.dbstate, self.uistate, self.track)
         src = sel.run()
@@ -331,12 +325,13 @@ class GalleryTab(ButtonTab, DbGUIElement):
             sref = MediaRef()
             try:
                 from .. import EditMediaRef
-                EditMediaRef(self.dbstate, self.uistate, self.track, 
+                EditMediaRef(self.dbstate, self.uistate, self.track,
                              src, sref, self.add_callback)
             except WindowActiveError:
                 from ...dialog import WarningDialog
                 WarningDialog(_("Cannot share this reference"),
-                              self.__blocked_text())
+                              self.__blocked_text(),
+                              parent=self.uistate.window)
 
     def del_button_clicked(self, obj):
         ref = self.get_selected()
@@ -347,16 +342,17 @@ class GalleryTab(ButtonTab, DbGUIElement):
     def edit_button_clicked(self, obj):
         ref = self.get_selected()
         if ref:
-            obj = self.dbstate.db.get_object_from_handle(
+            obj = self.dbstate.db.get_media_from_handle(
                                                 ref.get_reference_handle())
             try:
                 from .. import EditMediaRef
-                EditMediaRef(self.dbstate, self.uistate, self.track, 
+                EditMediaRef(self.dbstate, self.uistate, self.track,
                              obj, ref, self.edit_callback)
             except WindowActiveError:
                 from ...dialog import WarningDialog
                 WarningDialog(_("Cannot edit this reference"),
-                              self.__blocked_text())
+                              self.__blocked_text(),
+                              parent=self.uistate.window)
 
     def edit_callback(self, media_ref, media):
         """
@@ -381,7 +377,7 @@ class GalleryTab(ButtonTab, DbGUIElement):
                     pos = ref_handles.index(handle)
                 except ValueError :
                     break
-            
+
                 if pos is not None:
                     #oeps, we need to remove this reference, and rebuild tab
                     del self.media_list[pos]
@@ -427,7 +423,7 @@ class GalleryTab(ButtonTab, DbGUIElement):
         self.iconlist.connect('drag_data_get', self.drag_data_get)
         if not self.dbstate.db.readonly:
             self.iconlist.connect('drag_data_received', self.drag_data_received)
-        
+
     def drag_data_get(self, widget, context, sel_data, info, time):
         """
         Provide the drag_data_get function, which passes a tuple consisting of:
@@ -452,9 +448,9 @@ class GalleryTab(ButtonTab, DbGUIElement):
 
             if not obj:
                 return
-            
+
             # pickle the data, and build the tuple to be passed
-            value = (self._DND_TYPE.drag_type, id(self), obj, 
+            value = (self._DND_TYPE.drag_type, id(self), obj,
                      self.find_index(obj))
             data = pickle.dumps(value)
 
@@ -471,42 +467,55 @@ class GalleryTab(ButtonTab, DbGUIElement):
         and decide if this is a move or a reorder.
         """
         if sel_data and sel_data.get_data():
+            sel_list = []
             try:
-                (mytype, selfid, obj, row_from) = pickle.loads(sel_data.get_data())
+                rets = pickle.loads(sel_data.get_data())
 
-                # make sure this is the correct DND type for this object
-                if mytype == self._DND_TYPE.drag_type:
-                    
-                    # determine the destination row
-                    data = self.iconlist.get_dest_item_at_pos(x, y)
-                    if data:
-                        (path, pos) = data
-                        row = path.get_indices()[0]
-                        if pos ==  Gtk.IconViewDropPosition.DROP_LEFT:
-                            row = max(row, 0)
-                        elif pos == Gtk.IconViewDropPosition.DROP_RIGHT:
-                            row = min(row, len(self.get_data()))
-                        elif pos == Gtk.IconViewDropPosition.DROP_INTO:
-                            row = min(row+1, len(self.get_data()))
-                    else:
-                        row = len(self.get_data())
-                    
-                    # if the is same object, we have a move, otherwise,
-                    # it is a standard drag-n-drop
-                    
-                    if id(self) == selfid:
-                        self._move(row_from, row, obj)
-                    else:
-                        self._handle_drag(row, obj)
-                    self.rebuild()
-                elif mytype == DdTargets.MEDIAOBJ.drag_type:
-                    oref = MediaRef()
-                    oref.set_reference_handle(obj)
-                    self.get_data().append(oref)
-                    self.changed = True
-                    self.rebuild()
-                elif self._DND_EXTRA and mytype == self._DND_EXTRA.drag_type:
-                    self.handle_extra_type(mytype, obj)
+                # single dnd item
+                if isinstance(rets, tuple):
+                    sel_list.append(rets)
+
+                # multiple dnd items
+                elif isinstance(rets, list):
+                    for ret in rets:
+                        sel_list.append(pickle.loads(ret))
+
+                for sel in sel_list:
+                    (mytype, selfid, obj, row_from) = sel
+
+                    # make sure this is the correct DND type for this object
+                    if mytype == self._DND_TYPE.drag_type:
+
+                        # determine the destination row
+                        data = self.iconlist.get_dest_item_at_pos(x, y)
+                        if data:
+                            (path, pos) = data
+                            row = path.get_indices()[0]
+                            if pos ==  Gtk.IconViewDropPosition.DROP_LEFT:
+                                row = max(row, 0)
+                            elif pos == Gtk.IconViewDropPosition.DROP_RIGHT:
+                                row = min(row, len(self.get_data()))
+                            elif pos == Gtk.IconViewDropPosition.DROP_INTO:
+                                row = min(row+1, len(self.get_data()))
+                        else:
+                            row = len(self.get_data())
+
+                        # if the is same object, we have a move, otherwise,
+                        # it is a standard drag-n-drop
+
+                        if id(self) == selfid:
+                            self._move(row_from, row, obj)
+                        else:
+                            self._handle_drag(row, obj)
+                        self.rebuild()
+                    elif mytype == DdTargets.MEDIAOBJ.drag_type:
+                        oref = MediaRef()
+                        oref.set_reference_handle(obj)
+                        self.get_data().append(oref)
+                        self.changed = True
+                        self.rebuild()
+                    elif self._DND_EXTRA and mytype == self._DND_EXTRA.drag_type:
+                        self.handle_extra_type(mytype, obj)
             except pickle.UnpicklingError:
                 files =  sel_data.get_uris()
                 for file in files:
@@ -516,7 +525,7 @@ class GalleryTab(ButtonTab, DbGUIElement):
                         mime = get_type(name)
                         if not is_valid_type(mime):
                             return
-                        photo = MediaObject()
+                        photo = Media()
                         self.uistate.set_busy_cursor(True)
                         photo.set_checksum(create_checksum(name))
                         self.uistate.set_busy_cursor(False)
@@ -530,7 +539,7 @@ class GalleryTab(ButtonTab, DbGUIElement):
                         photo.set_description(root)
                         with DbTxn(_("Drag Media Object"),
                                    self.dbstate.db) as trans:
-                            self.dbstate.db.add_object(photo, trans)
+                            self.dbstate.db.add_media(photo, trans)
                             oref = MediaRef()
                             oref.set_reference_handle(photo.get_handle())
                             self.get_data().append(oref)
