@@ -22,7 +22,7 @@
 #
 
 """
-EditPerson Dialog. Provide the interface to allow the GRAMPS program
+EditPerson Dialog. Provide the interface to allow the Gramps program
 to edit information about a particular Person.
 """
 
@@ -51,7 +51,7 @@ from gi.repository import Pango
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
 from gramps.gen.utils.file import media_path_full
-from ..thumbnails import get_thumbnail_image
+from gramps.gen.utils.thumbnails import get_thumbnail_image
 from ..utils import is_right_click, open_file_with_default_application
 from gramps.gen.utils.db import get_birth_or_fallback
 from gramps.gen.lib import NoteType, Person, Surname
@@ -90,7 +90,7 @@ _select_gender = ((True, False, False),
                   (False, True, False),
                   (False, False, True))
 
-class SingSurn(object):
+class SingSurn:
     """
     Managing the single surname components
     """
@@ -176,8 +176,6 @@ class EditPerson(EditPrimary):
         This is called by the base class of EditPrimary, and overridden here.
 
         """
-        self.width_key = 'interface.person-width'
-        self.height_key = 'interface.person-height'
         self.pname = self.obj.get_primary_name()
         self.should_guess_gender = (not self.obj.get_gramps_id() and
                                     self.obj.get_gender () ==
@@ -191,6 +189,7 @@ class EditPerson(EditPrimary):
 
         self.set_window(self.top.toplevel, None,
                         self.get_menu_title())
+        self.setup_configs('interface.person', 750, 550)
 
         self.obj_photo = self.top.get_object("personPix")
         self.frame_photo = self.top.get_object("frame5")
@@ -198,9 +197,6 @@ class EditPerson(EditPrimary):
         self.singsurnfr = SingSurn(self.top)
         self.multsurnfr = self.top.get_object("hboxmultsurnames")
         self.singlesurn_active = True
-        self.surntab = SurnameTab(self.dbstate, self.uistate, self.track,
-                                  self.obj.get_primary_name(),
-                                  on_change=self._changed_name)
 
         self.set_contexteventbox(self.top.get_object("eventboxtop"))
 
@@ -245,7 +241,7 @@ class EditPerson(EditPrimary):
                 WIKI_HELP_PAGE,
                 _('manual|Editing_information_about_people'))
 
-        self.given.connect("focus_out_event", self._given_focus_out_event)
+        self.given.connect("focus-out-event", self._given_focus_out_event)
         self.top.get_object("editnamebtn").connect("clicked",
                                                  self._edit_name_clicked)
         self.top.get_object("multsurnamebtn").connect("clicked",
@@ -259,8 +255,8 @@ class EditPerson(EditPrimary):
         tglist.add(DdTargets.PERSON_LINK.atom_drag_type,
                    DdTargets.PERSON_LINK.target_flags,
                    DdTargets.PERSON_LINK.app_id)
-        self.contexteventbox.drag_source_set(Gdk.ModifierType.BUTTON1_MASK, 
-                                   [], 
+        self.contexteventbox.drag_source_set(Gdk.ModifierType.BUTTON1_MASK,
+                                   [],
                                    Gdk.DragAction.COPY)
         self.contexteventbox.drag_source_set_target_list(tglist)
         self.contexteventbox.drag_source_set_icon_name('gramps-person')
@@ -301,7 +297,7 @@ class EditPerson(EditPrimary):
 
     def _update_families(self):
         phandle = self.obj.get_handle()
-        if phandle:
+        if self.dbstate.db.has_person_handle(phandle):
             #new person has no handle yet and cannot be in a family.
             person = self.dbstate.db.get_person_from_handle(phandle)
             self.obj.set_family_handle_list(person.get_family_handle_list())
@@ -446,6 +442,9 @@ class EditPerson(EditPrimary):
 
         self.preview_name = self.top.get_object("full_name")
         self.preview_name.override_font(Pango.FontDescription('sans bold 12'))
+        self.surntab = SurnameTab(self.dbstate, self.uistate, self.track,
+                                  self.obj.get_primary_name(),
+                                  on_change=self._changed_name)
 
     def get_start_date(self):
         """
@@ -484,7 +483,7 @@ class EditPerson(EditPrimary):
         self.srcref_list = CitationEmbedList(self.dbstate,
                                            self.uistate,
                                            self.track,
-                                           self.obj.get_citation_list(), 
+                                           self.obj.get_citation_list(),
                                            self.get_menu_title())
         self._add_tab(notebook, self.srcref_list)
         self.track_ref_for_deletion("srcref_list")
@@ -621,7 +620,7 @@ class EditPerson(EditPrimary):
             if media_list:
                 media_ref = media_list[0]
                 object_handle = media_ref.get_reference_handle()
-                media_obj = self.db.get_object_from_handle(object_handle)
+                media_obj = self.db.get_media_from_handle(object_handle)
 
                 try:
                     EditMediaRef(self.dbstate, self.uistate, self.track,
@@ -645,7 +644,7 @@ class EditPerson(EditPrimary):
         self.imgmenu = Gtk.Menu()
         menu = self.imgmenu
         menu.set_title(_("Media Object"))
-        obj = self.db.get_object_from_handle(photo.get_reference_handle())
+        obj = self.db.get_media_from_handle(photo.get_reference_handle())
         if obj:
             add_menuitem(menu, _("View"), photo,
                                    self._popup_view_photo)
@@ -661,9 +660,9 @@ class EditPerson(EditPrimary):
         if media_list:
             photo = media_list[0]
             object_handle = photo.get_reference_handle()
-            ref_obj = self.db.get_object_from_handle(object_handle)
+            ref_obj = self.db.get_media_from_handle(object_handle)
             photo_path = media_path_full(self.db, ref_obj.get_path())
-            open_file_with_default_application(photo_path)
+            open_file_with_default_application(photo_path, self.uistate)
 
     def _popup_change_description(self, obj):
         """
@@ -673,7 +672,7 @@ class EditPerson(EditPrimary):
         if media_list:
             media_ref = media_list[0]
             object_handle = media_ref.get_reference_handle()
-            media_obj = self.db.get_object_from_handle(object_handle)
+            media_obj = self.db.get_media_from_handle(object_handle)
             EditMediaRef(self.dbstate, self.uistate, self.track,
                          media_obj, media_ref, self.load_photo)
 
@@ -696,8 +695,8 @@ class EditPerson(EditPrimary):
                     None, None, self._make_home_person),
                 ])
 
-        self.all_action.set_visible(True)
-        self.home_action.set_visible(True)
+        self.all_action.set_visible(not self.added)
+        self.home_action.set_visible(not self.added)
 
         ui_top_cm = '''
             <menuitem action="ActivePerson"/>
@@ -747,7 +746,7 @@ class EditPerson(EditPrimary):
 
     def _check_for_unknown_gender(self):
         if self.obj.get_gender() == Person.UNKNOWN:
-            d = GenderDialog(self.window)
+            d = GenderDialog(parent=self.window)
             gender = d.run()
             d.destroy()
             if gender >= 0:
@@ -769,11 +768,9 @@ class EditPerson(EditPrimary):
             f.set_child_ref_list(new_order)
 
         error = False
-        original = self.db.get_person_from_handle(self.obj.handle)
-
-        if original:
+        if self.original:
             (female, male, unknown) = _select_gender[self.obj.get_gender()]
-            if male and original.get_gender() != Person.MALE:
+            if male and self.original.get_gender() != Person.MALE:
                 for tmp_handle in self.obj.get_family_handle_list():
                     temp_family = self.db.get_family_from_handle(tmp_handle)
                     if self.obj == temp_family.get_mother_handle():
@@ -782,7 +779,7 @@ class EditPerson(EditPrimary):
                         else:
                             temp_family.set_mother_handle(None)
                             temp_family.set_father_handle(self.obj)
-            elif female and original != Person.FEMALE:
+            elif female and self.original != Person.FEMALE:
                 for tmp_handle in self.obj.get_family_handle_list():
                     temp_family = self.db.get_family_from_handle(tmp_handle)
                     if self.obj == temp_family.get_father_handle():
@@ -791,7 +788,7 @@ class EditPerson(EditPrimary):
                         else:
                             temp_family.set_father_handle(None)
                             temp_family.set_mother_handle(self.obj)
-            elif unknown and original.get_gender() != Person.UNKNOWN:
+            elif unknown and self.original.get_gender() != Person.UNKNOWN:
                 for tmp_handle in self.obj.get_family_handle_list():
                     temp_family = self.db.get_family_from_handle(tmp_handle)
                     if self.obj == temp_family.get_father_handle():
@@ -859,21 +856,21 @@ class EditPerson(EditPrimary):
 
         self.db.set_birth_death_index(self.obj)
 
-        with DbTxn('', self.db) as trans:
-            self._update_family_ids()
-            if not self.obj.get_handle():
+        if not self.obj.handle:
+            with DbTxn(_("Add Person (%s)") % \
+                        self.name_displayer.display(self.obj),
+                       self.db) as trans:
                 self.db.add_person(self.obj, trans)
-                msg = _("Add Person (%s)") % \
-                        self.name_displayer.display(self.obj)
-            else:
-                if not self.obj.get_gramps_id():
-                    self.obj.set_gramps_id(self.db.find_next_person_gramps_id())
-                self.db.commit_person(self.obj, trans)
-                msg = _("Edit Person (%s)") % \
-                        self.name_displayer.display(self.obj)
-            trans.set_description(msg)
+        else:
+            if self.data_has_changed():
+                with DbTxn(_("Edit Person (%s)") % \
+                            self.name_displayer.display(self.obj),
+                           self.db) as trans:
+                    if not self.obj.get_gramps_id():
+                        self.obj.set_gramps_id(self.db.find_next_person_gramps_id())
+                    self.db.commit_person(self.obj, trans)
 
-        self.close()
+        self._do_close()
         if self.callback:
             self.callback(self.obj)
         self.callback = None
@@ -939,7 +936,8 @@ class EditPerson(EditPrimary):
         msurhbox = self.top.get_object("hboxmultsurnames")
         msurhbox.remove(self.surntab)
         self.surntab = SurnameTab(self.dbstate, self.uistate, self.track,
-                       self.obj.get_primary_name())
+                                  self.obj.get_primary_name(),
+                                  on_change=self._changed_name)
         self.multsurnfr.set_size_request(-1,
                                 int(config.get('interface.surname-box-height')))
         msurhbox.pack_start(self.surntab, True, True, 0)
@@ -955,12 +953,13 @@ class EditPerson(EditPrimary):
         if media_list:
             ref = media_list[0]
             handle = ref.get_reference_handle()
-            obj = self.dbstate.db.get_object_from_handle(handle)
+            obj = self.dbstate.db.get_media_from_handle(handle)
             if obj is None :
                 #notify user of error
                 from ..dialog import RunDatabaseRepair
                 RunDatabaseRepair(
-                            _('Non existing media found in the Gallery'))
+                    _('Non existing media found in the Gallery'),
+                    parent=self.window)
             else :
                 self.load_photo(ref, obj)
         else:
@@ -972,8 +971,8 @@ class EditPerson(EditPrimary):
         Load the person's main photo using the Thumbnailer.
         """
         pixbuf = get_thumbnail_image(
-                        media_path_full(self.dbstate.db, 
-                                              obj.get_path()), 
+                        media_path_full(self.dbstate.db,
+                                              obj.get_path()),
                         obj.get_mime_type(),
                         ref.get_rectangle())
 
