@@ -21,14 +21,14 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
+""" The ReportDialog base class """
+
 #-------------------------------------------------------------------------
 #
 # Python modules
 #
 #-------------------------------------------------------------------------
 import os
-import threading
-import time
 
 import logging
 LOG = logging.getLogger(".")
@@ -42,26 +42,28 @@ from gi.repository import Gtk
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
-from gramps.gen.const import GRAMPS_LOCALE as glocale,  URL_MANUAL_PAGE
-_ = glocale.translation.gettext
 from gramps.gen.config import config
-from gramps.gen.errors import DatabaseError, FilterError, ReportError, WindowActiveError
+from gramps.gen.const import URL_MANUAL_PAGE, DOCGEN_OPTIONS
+from gramps.gen.errors import (DatabaseError, FilterError, ReportError,
+                               WindowActiveError)
 from ...utils import open_file_with_default_application
 from .. import add_gui_options, make_gui_option
 from ...user import User
 from ...dialog import ErrorDialog, OptionDialog
 from gramps.gen.plug.report import (CATEGORY_TEXT, CATEGORY_DRAW, CATEGORY_BOOK,
-                             CATEGORY_CODE, CATEGORY_WEB, CATEGORY_GRAPHVIZ,
-                             standalone_categories)
+                                    CATEGORY_CODE, CATEGORY_WEB,
+                                    CATEGORY_GRAPHVIZ, CATEGORY_TREE,
+                                    standalone_categories)
 from gramps.gen.plug.docgen import StyleSheet, StyleSheetList
 from ...managedwindow import ManagedWindow
 from ._stylecombobox import StyleComboBox
 from ._styleeditor import StyleListDisplay
 from ._fileentry import FileEntry
-from gramps.gen.constfunc import conv_to_unicode
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
 #-------------------------------------------------------------------------
 #
 # Private Constants
@@ -87,7 +89,7 @@ class ReportDialog(ManagedWindow):
                  track=[]):
         """Initialize a dialog to request that the user select options
         for a basic *stand-alone* report."""
-        
+
         self.style_name = "default"
         self.firstpage_added = False
         self.raw_name = name
@@ -95,7 +97,7 @@ class ReportDialog(ManagedWindow):
         self.uistate = uistate
         self.db = dbstate.db
         self.report_name = trans_name
-        
+
         ManagedWindow.__init__(self, uistate, track, self)
 
         self.init_options(option_class)
@@ -150,7 +152,7 @@ class ReportDialog(ManagedWindow):
 
         self.style_name = self.options.handler.get_default_stylesheet_name()
 
-        window = Gtk.Dialog('Gramps')
+        window = Gtk.Dialog(title='Gramps')
         self.set_window(window, None, self.get_title())
         self.window.set_modal(True)
 
@@ -164,7 +166,7 @@ class ReportDialog(ManagedWindow):
         self.ok = self.window.add_button(_('_OK'), Gtk.ResponseType.OK)
         self.ok.connect('clicked', self.on_ok_clicked)
 
-        self.window.set_position(Gtk.WindowPosition.CENTER)
+        self.window.set_position(Gtk.WindowPosition.CENTER_ON_PARENT)
         self.window.set_default_size(600, -1)
 
         # Set up and run the dialog.  These calls are not in top down
@@ -193,7 +195,8 @@ class ReportDialog(ManagedWindow):
         self.notebook.set_border_width(6)
         try:
             #assume a vbox or hbox
-            self.window.vbox.pack_start(self.notebook, expand=True, fill=True, padding=0)
+            self.window.vbox.pack_start(self.notebook,
+                                        expand=True, fill=True, padding=0)
         except:
             #general container instead:
             self.window.vbox.add(self.notebook)
@@ -204,7 +207,8 @@ class ReportDialog(ManagedWindow):
 
         try:
             #assume a vbox or hbox
-            self.window.vbox.pack_start(self.grid, expand=True, fill=True, padding=0)
+            self.window.vbox.pack_start(self.grid,
+                                        expand=True, fill=True, padding=0)
         except:
             #general container instead:
             self.window.vbox.add(self.grid)
@@ -215,7 +219,7 @@ class ReportDialog(ManagedWindow):
         name = self.report_name
         category = standalone_categories[self.category][1]
         return "%s - %s - Gramps" % (name, category)
-    
+
     #------------------------------------------------------------------------
     #
     # Functions related to extending the options
@@ -230,13 +234,13 @@ class ReportDialog(ManagedWindow):
 
     def parse_user_options(self):
         """Called to allow parsing of added widgets.
-        It is called when OK is pressed in a dialog. 
+        It is called when OK is pressed in a dialog.
         All custom widgets should provide a parsing code here."""
         try:
             self.options.parse_user_options()
         except:
             LOG.error("Failed to parse user options.", exc_info=True)
-            
+
     def add_option(self, label_text, widget):
         """Takes a text string and a Gtk Widget, and stores them to be
         appended to the Options section of the dialog. The text string
@@ -256,13 +260,13 @@ class ReportDialog(ManagedWindow):
         all managing of the widgets, including extracting the final value
         before the report executes. This task should only be called in
         the add_user_options task."""
-        
+
         if frame_name in self.frames:
             self.frames[frame_name].append((label_text, widget))
         else:
             self.frames[frame_name] = [(label_text, widget)]
             self.frame_names.append(frame_name)
-        
+
     #------------------------------------------------------------------------
     #
     # Functions to create a default output style.
@@ -277,13 +281,13 @@ class ReportDialog(ManagedWindow):
         created here instead of inline with the rest of the style
         frame, because it must be recreated to reflect any changes
         whenever the user closes the style editor dialog."""
-        
+
         if default is None:
             default = self.style_name
-            
+
         style_sheet_map = self.style_sheet_list.get_style_sheet_map()
         self.style_menu.set(style_sheet_map, default)
-        
+
     #------------------------------------------------------------------------
     #
     # Functions related to setting up the dialog window.
@@ -297,11 +301,11 @@ class ReportDialog(ManagedWindow):
 
     def setup_header(self):
         """Set up the header line bar of the dialog."""
-        label = Gtk.Label(label='<span size="larger" weight="bold">%s</span>' % 
+        label = Gtk.Label(label='<span size="larger" weight="bold">%s</span>' %
                           self.report_name)
         label.set_use_markup(True)
         self.window.vbox.pack_start(label, False, False, self.border_pad)
-        
+
     def setup_style_frame(self):
         """Set up the style frame of the dialog.  This function relies
         on other routines to create the default style for this report,
@@ -317,25 +321,24 @@ class ReportDialog(ManagedWindow):
             return
 
         # Styles Frame
-        label = Gtk.Label(label="%s:" % _("Style"))
+        label = Gtk.Label(label=_("%s:") % _("Style"))
         label.set_halign(Gtk.Align.START)
 
         self.style_menu = StyleComboBox()
         self.style_menu.set_hexpand(True)
-        self.style_button = Gtk.Button("%s..." % _("Style Editor"))
+        self.style_button = Gtk.Button(label="%s..." % _("Style Editor"))
         self.style_button.connect('clicked', self.on_style_edit_clicked)
 
         self.grid.attach(label, 1, self.row, 1, 1)
         self.grid.attach(self.style_menu, 2, self.row, 1, 1)
         self.grid.attach(self.style_button, 3, self.row, 1, 1)
         self.row += 1
-        
+
         # Build the initial list of available styles sets.  This
         # includes the default style set and any style sets saved from
         # previous invocations of gramps.
         self.style_sheet_list = StyleSheetList(
-                            self.options.handler.get_stylesheet_savefile(),
-                            self.default_style)
+            self.options.handler.get_stylesheet_savefile(), self.default_style)
 
         # Now build the actual menu.
         style = self.options.handler.get_default_stylesheet_name()
@@ -359,18 +362,19 @@ class ReportDialog(ManagedWindow):
         grid.set_border_width(6)
         grid.set_column_spacing(12)
         grid.set_row_spacing(6)
-        
+
         label = Gtk.Label(label="<b>%s</b>" % _("Report Options"))
         label.set_halign(Gtk.Align.START)
         label.set_use_markup(True)
-        
+
         self.notebook.append_page(grid, label)
 
         # Setup requested widgets
         for (text, widget) in self.widgets:
             widget.set_hexpand(True)
             if text:
-                text_widget = Gtk.Label(label="%s:" % text)
+                # translators: needed for French, ignore otherwise
+                text_widget = Gtk.Label(label=_("%s:") % text)
                 text_widget.set_halign(Gtk.Align.START)
                 grid.attach(text_widget, 1, row, 1, 1)
                 grid.attach(widget, 2, row, 1, 1)
@@ -379,7 +383,7 @@ class ReportDialog(ManagedWindow):
             row += 1
 
     def setup_other_frames(self):
-        from gramps.gui.plug._guioptions import GuiTextOption
+        from .._guioptions import GuiTextOption
         for key in self.frame_names:
             flist = self.frames[key]
             grid = Gtk.Grid()
@@ -394,7 +398,7 @@ class ReportDialog(ManagedWindow):
             for (text, widget) in flist:
                 widget.set_hexpand(True)
                 if text:
-                    text_widget = Gtk.Label(label='%s:' % text)
+                    text_widget = Gtk.Label(label=_('%s:') % text)
                     text_widget.set_halign(Gtk.Align.START)
                     grid.attach(text_widget, 1, row, 1, 1)
                     if isinstance(widget, GuiTextOption):
@@ -404,13 +408,13 @@ class ReportDialog(ManagedWindow):
                 else:
                     grid.attach(widget, 2, row, 1, 1)
                 row += 1
-                
+
     #------------------------------------------------------------------------
     #
     # Customization hooks for stand-alone reports (subclass ReportDialog)
     #
     #------------------------------------------------------------------------
-    def setup_format_frame(self): 
+    def setup_format_frame(self):
         """Not used in bare report dialogs. Override in the subclass."""
         pass
 
@@ -445,7 +449,8 @@ class ReportDialog(ManagedWindow):
         hid = self.style_name
         if hid[-4:] == ".xml":
             hid = hid[0:-4]
-        self.target_fileentry = FileEntry(hid, _("Save As"), parent=self.window)
+        self.target_fileentry = FileEntry(hid, _("Save As"),
+                                          parent=self.window)
         spath = self.get_default_directory()
         self.target_fileentry.set_filename(spath)
         # need any labels at top:
@@ -455,7 +460,7 @@ class ReportDialog(ManagedWindow):
         self.grid.set_border_width(12)
         self.grid.attach(label, 0, self.row, 4, 1)
         self.row += 1
-        
+
     def setup_target_frame(self):
         """Set up the target frame of the dialog.  This function
         relies on several target_xxx() customization functions to
@@ -464,14 +469,14 @@ class ReportDialog(ManagedWindow):
         directory should be used."""
 
         # Save Frame
-        self.doc_label = Gtk.Label(label="%s:" % _("Filename"))
+        self.doc_label = Gtk.Label(label=_("%s:") % _("Filename"))
         self.doc_label.set_halign(Gtk.Align.START)
 
         self.grid.attach(self.doc_label, 1, self.row, 1, 1)
         self.target_fileentry.set_hexpand(True)
         self.grid.attach(self.target_fileentry, 2, self.row, 2, 1)
         self.row += 1
-        
+
     #------------------------------------------------------------------------
     #
     # Functions related to retrieving data from the dialog window
@@ -483,7 +488,7 @@ class ReportDialog(ManagedWindow):
         to tell the calling routine to give up.  This function also
         saves the current directory so that any future reports will
         default to the most recently used directory."""
-        self.target_path = conv_to_unicode(self.target_fileentry.get_full_path(0))
+        self.target_path = self.target_fileentry.get_full_path(0)
         if not self.target_path:
             return None
 
@@ -505,14 +510,14 @@ class ReportDialog(ManagedWindow):
 
             # selected path is an existing file and we need a file
             if os.path.isfile(self.target_path):
-                a = OptionDialog(_('File already exists'),
-                                 _('You can choose to either overwrite the '
-                                   'file, or change the selected filename.'),
-                                 _('_Overwrite'), None,
-                                 _('_Change filename'), None,
-                                 parent=self.window)
-                             
-                if a.get_response() == Gtk.ResponseType.YES:
+                aaa = OptionDialog(_('File already exists'),
+                                   _('You can choose to either overwrite the '
+                                     'file, or change the selected filename.'),
+                                   _('_Overwrite'), None,
+                                   _('_Change filename'), None,
+                                   parent=self.window)
+
+                if aaa.get_response() == Gtk.ResponseType.YES:
                     return None
 
         # selected path does not exist yet
@@ -536,11 +541,11 @@ class ReportDialog(ManagedWindow):
                               'or create it.') % parent_dir,
                             parent=self.window)
                 return None
-        
+
         self.set_default_directory(os.path.dirname(self.target_path) + os.sep)
         self.options.handler.output = self.target_path
         return 1
-    
+
     def parse_style_frame(self):
         """Parse the style frame of the dialog.  Save the user
         selected output style for later use.  Note that this routine
@@ -568,24 +573,24 @@ class ReportDialog(ManagedWindow):
         # Preparation
         self.parse_style_frame()
         self.parse_user_options()
-        
+
         # Save options
         self.options.handler.save_options()
-        
+
     def on_cancel(self, *obj):
         pass
 
     def on_help_clicked(self, *obj):
         from ...display import display_help
         display_help(URL_REPORT_PAGE, self.report_name.replace(" ", "_"))
-        
+
     def on_style_edit_clicked(self, *obj):
         """The user has clicked on the 'Edit Styles' button.  Create a
         style sheet editor object and let them play.  When they are
         done, the previous routine will be called to update the dialog
         menu for selecting a style."""
-        StyleListDisplay(self.style_sheet_list, self.build_style_menu,
-                         self.window)
+        StyleListDisplay(self.style_sheet_list, self.uistate, self.track,
+                         callback=self.build_style_menu)
 
     #----------------------------------------------------------------------
     #
@@ -604,15 +609,15 @@ class ReportDialog(ManagedWindow):
 
         self.init_doc_options(self.doc_option_class)
         menu = self.doc_options.menu
-        for name in menu.get_option_names('Document Options'):
-            option = menu.get_option('Document Options', name)
+        for name in menu.get_option_names(DOCGEN_OPTIONS):
+            option = menu.get_option(DOCGEN_OPTIONS, name)
             # override option default with xml-saved value:
             if name in self.doc_options.options_dict:
                 option.set_value(self.doc_options.options_dict[name])
             widget, has_label = make_gui_option(option, self.dbstate,
                                                 self.uistate, self.track)
             if has_label:
-                widget_text = Gtk.Label('%s:' % option.get_label())
+                widget_text = Gtk.Label(label=(_('%s:') % option.get_label()))
                 widget_text.set_halign(Gtk.Align.START)
                 self.grid.attach(widget_text, 1, self.row, 1, 1)
                 self.doc_widgets.append(widget_text)
@@ -622,8 +627,7 @@ class ReportDialog(ManagedWindow):
 
     def init_doc_options(self, option_class):
         try:
-            if (issubclass(option_class, object) or     # New-style class
-                isinstance(option_class, ClassType)):   # Old-style class
+            if issubclass(option_class, object):
                 self.doc_options = option_class(self.raw_name, self.db)
         except TypeError:
             self.doc_options = option_class
@@ -632,7 +636,7 @@ class ReportDialog(ManagedWindow):
     def parse_doc_options(self):
         """
         Called to allow parsing of added docgen widgets.
-        It is called when OK is pressed in a dialog. 
+        It is called when OK is pressed in a dialog.
         """
         if not self.doc_options:
             return
@@ -673,6 +677,9 @@ def report(dbstate, uistate, person, report_class, options_class,
     elif category == CATEGORY_GRAPHVIZ:
         from ._graphvizreportdialog import GraphvizReportDialog
         dialog_class = GraphvizReportDialog
+    elif category == CATEGORY_TREE:
+        from ._treereportdialog import TreeReportDialog
+        dialog_class = TreeReportDialog
     elif category == CATEGORY_WEB:
         from ._webreportdialog import WebReportDialog
         dialog_class = WebReportDialog
@@ -681,7 +688,7 @@ def report(dbstate, uistate, person, report_class, options_class,
             report_class(dbstate, uistate)
         except WindowActiveError:
             pass
-        return        
+        return
     else:
         dialog_class = ReportDialog
 
@@ -693,41 +700,44 @@ def report(dbstate, uistate, person, report_class, options_class,
             dialog.close()
             try:
                 user = User(uistate=uistate)
-                MyReport = report_class(dialog.db, dialog.options, user)
-                MyReport.doc.init()
-                MyReport.begin_report()
-                MyReport.write_report()
-                MyReport.end_report()
+                my_report = report_class(dialog.db, dialog.options, user)
+                my_report.doc.init()
+                my_report.begin_report()
+                my_report.write_report()
+                my_report.end_report()
 
-                # Web reports do not have a target frame      
+                # Web reports do not have a target frame
                 # The GtkPrint generator can not be "opened"
-                if hasattr(dialog, "open_with_app")                        and \
-                   dialog.open_with_app.get_property('sensitive') == True  and \
-                   dialog.open_with_app.get_active():
+                if (hasattr(dialog, "open_with_app") and
+                        dialog.open_with_app.get_property('sensitive') == True
+                        and dialog.open_with_app.get_active()):
                     out_file = dialog.options.get_output()
-                    open_file_with_default_application(out_file)
-                
+                    open_file_with_default_application(out_file, uistate)
+
             except FilterError as msg:
-                (m1, m2) = msg.messages()
-                ErrorDialog(m1, m2, parent=uistate.window)
+                (msg1, msg2) = msg.messages()
+                ErrorDialog(msg1, msg2, parent=uistate.window)
             except IOError as msg:
-                ErrorDialog(_("Report could not be created"), str(msg),
+                ErrorDialog(_("Report could not be created"),
+                            str(msg),
                             parent=uistate.window)
             except ReportError as msg:
-                (m1, m2) = msg.messages()
-                ErrorDialog(m1, m2, parent=uistate.window)
-            except DatabaseError as msg:                
-                ErrorDialog(_("Report could not be created"), str(msg),
+                (msg1, msg2) = msg.messages()
+                ErrorDialog(msg1, msg2, parent=uistate.window)
+            except DatabaseError as msg:
+                ErrorDialog(_("Report could not be created"),
+                            str(msg),
                             parent=uistate.window)
 #           The following except statement will catch all "NoneType" exceptions.
 #           This is useful for released code where the exception is most likely
 #           a corrupt database. But it is less useful for developing new reports
-#           where the exception is most likely a report bug.                
+#           where the exception is most likely a report bug.
 #            except AttributeError,msg:
 #                if str(msg).startswith("'NoneType' object has no attribute"):
 #                    # "'NoneType' object has no attribute ..." usually means
 #                    # database corruption
-#                    RunDatabaseRepair(str(msg))
+#                    RunDatabaseRepair(str(msg),
+#                                      parent=self.window)
 #                else:
 #                    raise
                 raise
@@ -741,6 +751,7 @@ def report(dbstate, uistate, person, report_class, options_class,
             #just stop, in ManagedWindow, delete-event is already coupled to
             #correct action.
             break
+
     #do needed cleanup
     dialog.db = None
     dialog.options = None
