@@ -5,7 +5,7 @@
 # Copyright (C) 2007-2008  Brian G. Matherly
 # Copyright (C) 2008       Peter Landgren
 # Copyright (C) 2010       Jakim Friant
-# Copyright (C) 2012       Paul Franklin
+# Copyright (C) 2012,2017  Paul Franklin
 # Copyright (C) 2014       Nick Hall
 #
 # This program is free software; you can redistribute it and/or modify
@@ -13,7 +13,7 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful, 
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
@@ -32,8 +32,6 @@ Paragraph/Font style editor
 # Python modules
 #
 #------------------------------------------------------------------------
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.sgettext
 import logging
 log = logging.getLogger(".")
 import re
@@ -47,70 +45,84 @@ from gi.repository import Gtk, Gdk
 
 #------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #------------------------------------------------------------------------
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.sgettext
 from gramps.gen.plug.docgen import (StyleSheet, FONT_SERIF, FONT_SANS_SERIF,
-            PARA_ALIGN_RIGHT, PARA_ALIGN_CENTER, PARA_ALIGN_LEFT,  
+            PARA_ALIGN_RIGHT, PARA_ALIGN_CENTER, PARA_ALIGN_LEFT,
             PARA_ALIGN_JUSTIFY, ParagraphStyle, TableStyle, TableCellStyle,
             GraphicsStyle)
 from ...listmodel import ListModel
-from ...managedwindow import set_titles
+from ...managedwindow import ManagedWindow
 from ...glade import Glade
+from ...dialog import ErrorDialog
 
 #------------------------------------------------------------------------
 #
 # StyleListDisplay class
 #
 #------------------------------------------------------------------------
-class StyleListDisplay(object):
+class StyleListDisplay(ManagedWindow):
     """
-    Shows the available paragraph/font styles. Allows the user to select, 
-    add, edit, and delete styles from a StyleSheet.
+    Shows the available paragraph/font styles. Allows the user to select,
+    add, edit, and delete styles from a StyleSheetList.
     """
 
-    def __init__(self, stylesheetlist, callback, parent_window):
+    def __init__(self, stylesheetlist, uistate, track, callback=None):
         """
         Create a StyleListDisplay object that displays the styles in the
-        StyleSheet.
+        StyleSheetList.
 
-        stylesheetlist - styles that can be editied
-        callback - task called with an object has been added.
+        stylesheetlist - styles for editing: a :class:`.StyleSheetList` instance
+        callback - task called when an object has been added.
         """
-        self.callback = callback
-        
-        self.sheetlist = stylesheetlist
-        
-        self.top = Glade(toplevel='styles')
-        self.window = self.top.toplevel
 
-        set_titles(self.window, self.top.get_object('title'), 
-                   _('Document Styles'))
+        ManagedWindow.__init__(self, uistate, track, self.__class__, modal=True)
+        # the self.window.run() below makes Gtk make it modal, so any change
+        # to the previous line's "modal" would require that line to be changed
+
+        self.callback = callback
+
+        self.sheetlist = stylesheetlist
+
+        self.top = Glade(toplevel='styles')
+        self.set_window(self.top.toplevel, self.top.get_object('title'),
+                        _('Document Styles'))
+        self.setup_configs('interface.stylelistdisplay', 400, 300)
+        self.show()
 
         self.top.connect_signals({
-            "destroy_passed_object" : self.__close,
-            "on_ok_clicked" : self.on_ok_clicked, 
-            "on_add_clicked" : self.on_add_clicked, 
-            "on_delete_clicked" : self.on_delete_clicked, 
-            "on_button_press" : self.on_button_press, 
+            "on_ok_clicked" : self.on_ok_clicked,
+            "on_add_clicked" : self.on_add_clicked,
+            "on_delete_clicked" : self.on_delete_clicked,
+            "on_button_press" : self.on_button_press,
             "on_edit_clicked" : self.on_edit_clicked,
+            "on_cancel_clicked" : self.__cancel,
+            "on_cancel_style_clicked" : dummy_callback,
             "on_save_style_clicked" : dummy_callback,
             })
 
-        self.list = ListModel(self.top.get_object("list"), 
+        self.list = ListModel(self.top.get_object("list"),
                                         [(_('Style'), -1, 10)], )
         self.redraw()
-        if parent_window:
-            self.window.set_transient_for(parent_window)
+        # the self.window.run() makes Gtk make it modal, so any change to that
+        # line would require the ManagedWindow.__init__ to be changed also
         self.window.run()
-        self.window.destroy()
+        if self.opened:
+            self.close()
 
-    def __close(self, obj):
-        self.top.destroy()
+    def build_menu_names(self, obj): # meaningless while it's modal
+        """Override :class:`.ManagedWindow` method."""
+        return (_('Document Styles'), ' ')
+
+    def __cancel(self, obj):
+        pass
 
     def redraw(self):
-        """Redraws the list of styles that are current available"""
-        
+        """Redraws the list of styles that are currently available"""
+
         self.list.model.clear()
         self.list.add([_("default")])
 
@@ -122,38 +134,39 @@ class StyleListDisplay(object):
             index += 1
 
     def on_add_clicked(self, obj):
-        """Called with the ADD button is clicked. Invokes the StyleEditor to
+        """Called when the ADD button is clicked. Invokes the StyleEditor to
         create a new style"""
         style = self.sheetlist.get_style_sheet("default")
         StyleEditor(_("New Style"), style, self)
 
     def on_ok_clicked(self, obj):
-        """Called with the OK button is clicked; Calls the callback task, 
+        """Called when the OK button is clicked; Calls the callback task,
         then saves the stylesheet."""
         if self.callback is not None:
             self.callback()
         try:
             self.sheetlist.save()
         except IOError as msg:
-            from ...dialog import ErrorDialog
-            ErrorDialog(_("Error saving stylesheet"),
-                        str(msg), parent=self.window)
+            ErrorDialog(_("Error saving stylesheet"), str(msg),
+                        parent=self.window)
         except:
             log.error("Failed to save stylesheet", exc_info=True)
 
     def on_button_press(self, obj, event):
         if event.type == Gdk.EventType._2BUTTON_PRESS and event.button == 1:
             self.on_edit_clicked(obj)
-            
+
     def on_edit_clicked(self, obj):
         """
-        Called with the EDIT button is clicked.
+        Called when the EDIT button is clicked.
         Calls the StyleEditor to edit the selected style.
         """
         store, node = self.list.selection.get_selected()
         if not node:
+            ErrorDialog(_("Missing information"), _("Select a style"),
+                        parent=self.window)
             return
-        
+
         name = str(self.list.model.get_value(node, 0))
         if name == _('default'): # the default style cannot be edited
             return
@@ -164,6 +177,8 @@ class StyleListDisplay(object):
         """Deletes the selected style."""
         store, node = self.list.selection.get_selected()
         if not node:
+            ErrorDialog(_("Missing information"), _("Select a style"),
+                        parent=self.window)
             return
         name = str(self.list.model.get_value(node, 0))
         if name == _('default'): # the default style cannot be removed
@@ -176,35 +191,50 @@ class StyleListDisplay(object):
 # StyleEditor class
 #
 #------------------------------------------------------------------------
-class StyleEditor(object):
+class StyleEditor(ManagedWindow):
     """
-    Edits the current style definition. Presents a dialog allowing the values
-    of the paragraphs in the style to be altered.
+    Edits the current style definition.
+    Presents a dialog allowing the values in the style to be altered.
     """
-    
+
     def __init__(self, name, style, parent):
         """
         Create the StyleEditor.
 
         name - name of the style that is to be edited
-        style - style object that is to be edited
+        style - style object to be edited: a :class:`.StyleSheet` instance
         parent - StyleListDisplay object that called the editor
         """
+
+        ManagedWindow.__init__(self, parent.uistate, parent.track,
+                               self.__class__, modal=True)
+        # the self.window.run() below makes Gtk make it modal, so any change
+        # to the previous line's "modal" would require that line to be changed
+
         self.current_style = None
         self.current_name = None
-        
+
         self.style = StyleSheet(style)
         self.parent = parent
-        self.top = Glade(toplevel='editor')
-        self.window = self.top.toplevel
-        
+        self.top = Glade(
+            toplevel='editor',
+            also_load=[
+                "adjustment1", "adjustment2", "adjustment3", "adjustment4",
+                "adjustment5", "adjustment6", "adjustment7", "adjustment8",
+                "adjustment9", "adjustment10", "adjustment11"])
+        self.set_window(self.top.toplevel, self.top.get_object('title'),
+                        _('Style editor'))
+        self.setup_configs('interface.styleeditor', 550, 610)
+        self.show()
+
         self.top.connect_signals({
-            "on_save_style_clicked" : self.on_save_style_clicked, 
-            "destroy_passed_object" : self.__close,
-            "on_ok_clicked" : dummy_callback, 
-            "on_add_clicked" : dummy_callback, 
-            "on_delete_clicked" : dummy_callback, 
-            "on_button_press" : dummy_callback, 
+            "on_save_style_clicked" : self.on_save_style_clicked,
+            "on_cancel_style_clicked" : self.__cancel,
+            "on_cancel_clicked" : dummy_callback,
+            "on_ok_clicked" : dummy_callback,
+            "on_add_clicked" : dummy_callback,
+            "on_delete_clicked" : dummy_callback,
+            "on_button_press" : dummy_callback,
             "on_edit_clicked" : dummy_callback,
             })
 
@@ -224,12 +254,10 @@ class StyleEditor(object):
         self.line_style.pack_start(renderer_text, True)
         self.line_style.add_attribute(renderer_text, "text", 1)
 
-        set_titles(self.window, self.top.get_object('title'), 
-                   _('Style editor'))
         self.top.get_object("label6").set_text(_("point size|pt"))
-        
+
         titles = [(_('Style'), 0, 130)]
-        self.plist = ListModel(self.top.get_object("ptree"), titles, 
+        self.plist = ListModel(self.top.get_object("ptree"), titles,
                                          self.change_display)
 
         for widget_name in ('color', 'bgcolor', 'line_color', 'fill_color'):
@@ -258,14 +286,19 @@ class StyleEditor(object):
         for d_name in names:
             self.plist.add([d_name], self.style.get_draw_style(d_name))
         self.plist.select_row(0)
-        
-        if self.parent:
-            self.window.set_transient_for(parent.window)
-        self.window.run()
-        self.window.destroy()
 
-    def __close(self, obj):
-        self.window.destroy()
+        # the self.window.run() makes Gtk make it modal, so any change to that
+        # line would require the ManagedWindow.__init__ to be changed also
+        self.window.run()
+        if self.opened:
+            self.close()
+
+    def build_menu_names(self, obj): # meaningless while it's modal
+        """Override :class:`.ManagedWindow` method."""
+        return (_('Style editor'), None)
+
+    def __cancel(self, obj):
+        pass
 
     def show_pages(self, show_pages):
         """
@@ -303,7 +336,14 @@ class StyleEditor(object):
         self.pname.set_text( '<span size="larger" weight="bold">%s</span>' %
                              self.current_name)
         self.pname.set_use_markup(True)
-        self.pdescription.set_text(_("No description available") )
+
+        descr = g.get_description()
+        descr = descr or _("No description available")
+        p_style = g.get_paragraph_style()
+        if p_style:
+            para_note = _("(Embedded style '%s' must be edited separately)")
+            descr += '\n\n' + para_note % p_style
+        self.pdescription.set_text(descr)
 
         self.top.get_object("line_style").set_active(g.get_line_style())
         self.top.get_object("line_width").set_value(g.get_line_width())
@@ -324,7 +364,9 @@ class StyleEditor(object):
         self.pname.set_text( '<span size="larger" weight="bold">%s</span>' %
                              self.current_name)
         self.pname.set_use_markup(True)
-        self.pdescription.set_text(_("No description available") )
+
+        descr = c.get_description()
+        self.pdescription.set_text(descr or _("No description available"))
 
         self.top.get_object("cell_lborder").set_active(c.get_left_border())
         self.top.get_object("cell_rborder").set_active(c.get_right_border())
@@ -340,7 +382,9 @@ class StyleEditor(object):
         self.pname.set_text( '<span size="larger" weight="bold">%s</span>' %
                              self.current_name)
         self.pname.set_use_markup(True)
-        self.pdescription.set_text(_("No description available") )
+
+        descr = t.get_description()
+        self.pdescription.set_text(descr or _("No description available"))
 
         self.top.get_object("table_width").set_value(t.get_width())
 
@@ -374,7 +418,7 @@ class StyleEditor(object):
 
         descr = p.get_description()
         self.pdescription.set_text(descr or _("No description available") )
-        
+
         font = p.get_font()
         self.top.get_object("size").set_value(font.get_size())
         if font.get_type_face() == FONT_SERIF:
@@ -476,7 +520,7 @@ class StyleEditor(object):
         p = self.current_style
         font = p.get_font()
         font.set_size(self.top.get_object("size").get_value_as_int())
-    
+
         if self.top.get_object("roman").get_active():
             font.set_type_face(FONT_SERIF)
         else:
@@ -490,9 +534,9 @@ class StyleEditor(object):
         elif self.top.get_object("ralign").get_active():
             p.set_alignment(PARA_ALIGN_RIGHT)
         elif self.top.get_object("calign").get_active():
-            p.set_alignment(PARA_ALIGN_CENTER)            
+            p.set_alignment(PARA_ALIGN_CENTER)
         else:
-            p.set_alignment(PARA_ALIGN_JUSTIFY)            
+            p.set_alignment(PARA_ALIGN_JUSTIFY)
 
         p.set_right_margin(self.top.get_object("rmargin").get_value())
         p.set_left_margin(self.top.get_object("lmargin").get_value())
@@ -509,7 +553,7 @@ class StyleEditor(object):
         font.set_color(color2rgb(color))
         bg_color = self.top.get_object("bgcolor").get_color()
         p.set_background_color(color2rgb(bg_color))
-        
+
         self.style.add_paragraph_style(self.current_name, self.current_style)
 
     def on_save_style_clicked(self, obj):
@@ -523,7 +567,6 @@ class StyleEditor(object):
         self.style.set_name(name)
         self.parent.sheetlist.set_style_sheet(name, self.style)
         self.parent.redraw()
-        self.window.destroy()
 
     def change_display(self, obj):
         """
@@ -555,8 +598,8 @@ def color2rgb(color):
     return (color.red >> 8, color.green >> 8, color.blue >> 8)
 
 def dummy_callback(obj):
-    """Dummy callback to satisfy gtkbuilder on connect of signals. 
-    There are two widgets in the glade file, although only one is needed, 
+    """Dummy callback to satisfy gtkbuilder on connect of signals.
+    There are two widgets in the glade file, although only one is needed,
     the signals of the other must be connected too
     """
     pass
