@@ -8,7 +8,7 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful, 
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
@@ -27,6 +27,7 @@ Provide the base class for GRAMPS' DataView classes
 # python modules
 #
 #----------------------------------------------------------------
+from abc import ABCMeta, abstractmethod
 import logging
 _LOG = logging.getLogger('.pageview')
 
@@ -42,7 +43,7 @@ _ = glocale.translation.gettext
 
 #----------------------------------------------------------------
 #
-# GRAMPS 
+# Gramps
 #
 #----------------------------------------------------------------
 from gramps.gen.errors import WindowActiveError
@@ -57,12 +58,12 @@ from ..actiongroup import ActionGroup
 # PageView
 #
 #------------------------------------------------------------------------------
-class PageView(DbGUIElement):
+class PageView(DbGUIElement, metaclass=ABCMeta):
     """
-    The PageView class is the base class for all Data Views in GRAMPS.  All 
+    The PageView class is the base class for all Data Views in Gramps.  All
     Views should derive from this class. The ViewManager understands the public
     interface of this class
-    
+
     The following attributes are available
     ..attribute:: active
       is the view active at the moment (visible in Gramps as the main view)
@@ -70,11 +71,11 @@ class PageView(DbGUIElement):
       bool, is the view current with the database or not. A dirty view triggers
       a rebuild when it becomes active
     ..attribute:: _dirty_on_change_inactive
-      read/write bool by inheriting classes. 
+      read/write bool by inheriting classes.
       Views can behave two ways to signals:
-      1. if the view is inactive, set it dirty, and rebuild the view when 
+      1. if the view is inactive, set it dirty, and rebuild the view when
           it becomes active. In this case, this method returns True
-      2. if the view is inactive, try to stay in sync with database. Only 
+      2. if the view is inactive, try to stay in sync with database. Only
          rebuild or other large changes make view dirty
     ..attribute:: title
       title of the view
@@ -115,7 +116,7 @@ class PageView(DbGUIElement):
         self.active = False
         self._dirty_on_change_inactive = True
         self.func_list = {}
-        
+
         if isinstance(self.pdata.category, tuple):
             self.category, self.translated_category = self.pdata.category
         else:
@@ -125,11 +126,11 @@ class PageView(DbGUIElement):
         self.dbstate.connect('no-database', self.disable_action_group)
         self.dbstate.connect('database-changed', self.enable_action_group)
         self.uistate.window.connect("key-press-event", self.key_press_handler)
-        
+
         self.model = None
         self.selection = None
         self.handle_col = 0
-        
+
         self._config = None
         self.init_config()
 
@@ -155,7 +156,7 @@ class PageView(DbGUIElement):
         hpane = Gtk.Paned()
         vpane = Gtk.Paned(orientation=Gtk.Orientation.VERTICAL)
         hpane.pack1(vpane, resize=True, shrink=False)
-        hpane.pack2(self.sidebar, resize=False, shrink=True)
+        hpane.pack2(self.sidebar, resize=False, shrink=False)
         hpane.show()
         vpane.show()
 
@@ -163,11 +164,43 @@ class PageView(DbGUIElement):
         widget.show_all()
         vpane.pack1(widget, resize=True, shrink=False)
         vpane.pack2(self.bottombar, resize=False, shrink=True)
+        self._setup_slider_config(vpane, 'vpane.slider-position')
 
         self.sidebar_toggled(self.sidebar.get_property('visible'))
+        self.hpane_sig = hpane.connect("draw", self.set_page_slider)
 
         return hpane
 
+    def set_page_slider(self, widget, dummy):
+        """ Setup slider.  We have the page realized at this point. """
+        widget.disconnect(self.hpane_sig)
+        # get current width of pane
+        width = widget.get_allocated_width()
+        # default will use natural size for sidebar until it gets to 400 pix
+        side_ch = self.sidebar.get_children()  # Gtk Notebook
+        try:
+            vp_ch = side_ch[0].get_children()  # Gtk Viewport child
+            ch_width = vp_ch[0].get_preferred_width()[0] + 3
+        except AttributeError:
+            ch_width = 300  # needed if no Gramplet installed
+        pos = width - min(ch_width, 400)
+        self._setup_slider_config(widget, 'hpane.slider-position',
+                                  position=pos)
+
+    def _setup_slider_config(self, widget, setting, position=-1):
+        """
+        Setup the slider configuration setting.
+        """
+        self._config.register(setting, position)
+        widget.set_position(self._config.get(setting))
+        widget.connect('notify::position', self._position_changed, setting)
+
+    def _position_changed(self, widget, position, setting):
+        """
+        Called when the position property of the pane is changed.
+        """
+        self._config.set(setting, widget.get_position())
+
     def __sidebar_toggled(self, action):
         """
         Called when the sidebar is toggled.
@@ -202,7 +235,7 @@ class PageView(DbGUIElement):
         Returns a 2-tuple.  The first element is a tuple of sidebar gramplets
         and the second element is a tuple of bottombar gramplets.
 
-        Views should override this method to define default gramplets. 
+        Views should override this method to define default gramplets.
         """
         return ((), ())
 
@@ -238,12 +271,12 @@ class PageView(DbGUIElement):
             # Construct a drop:
             drag_type = obj2target(objclass)
             if drag_type:
-                class Selection(object):
+                class Selection:
                     def __init__(self, data):
                         self.data = data
                     def get_data(self):
                         return self.data
-                class Context(object):
+                class Context:
                     targets = [drag_type]
                     action = 1
                     def list_targets(self):
@@ -262,7 +295,7 @@ class PageView(DbGUIElement):
                 handled = True
         return handled
 
-    def call_paste(self): 
+    def call_paste(self):
         """
         This code is called on Control+V in a navigation view. If the
         copy can be handled, it returns true, otherwise false.
@@ -290,7 +323,7 @@ class PageView(DbGUIElement):
         Called after a page is created.
         """
         pass
-    
+
     def set_active(self):
         """
         Called with the PageView is set as active. If the page is "dirty",
@@ -303,7 +336,7 @@ class PageView(DbGUIElement):
             self.uistate.set_busy_cursor(True)
             self.build_tree()
             self.uistate.set_busy_cursor(False)
-            
+
     def set_inactive(self):
         """
         Marks page as being inactive (not currently displayed)
@@ -312,13 +345,13 @@ class PageView(DbGUIElement):
         self.bottombar.set_inactive()
         self.active = False
 
+    @abstractmethod
     def build_tree(self):
         """
         Rebuilds the current display. This must be overridden by the derived
         class.
         """
-        raise NotImplementedError
-    
+
     def ui_definition(self):
         """
         returns the XML UI definition for the UIManager
@@ -348,7 +381,7 @@ class PageView(DbGUIElement):
 
     def get_stock(self):
         """
-        Return image associated with the view category, which is used for the 
+        Return image associated with the view category, which is used for the
         icon for the button.
         """
         return 'image-missing'
@@ -389,30 +422,30 @@ class PageView(DbGUIElement):
             self.top = self.build_interface()
         return self.top
 
+    @abstractmethod
     def build_widget(self):
         """
         Builds the container widget for the main view pane. Must be overridden
         by the base class. Returns a gtk container widget.
         """
-        raise NotImplementedError
 
     def define_actions(self):
         """
         Defines the UIManager actions. Called by the ViewManager to set up the
-        View. The user typically defines self.action_list and 
-        self.action_toggle_list in this function. 
+        View. The user typically defines self.action_list and
+        self.action_toggle_list in this function.
         """
-        self._add_toggle_action('Sidebar', None, _('_Sidebar'), 
+        self._add_toggle_action('Sidebar', None, _('_Sidebar'),
              "<shift><PRIMARY>R", None, self.__sidebar_toggled,
              self.sidebar.get_property('visible'))
-        self._add_toggle_action('Bottombar', None, _('_Bottombar'), 
+        self._add_toggle_action('Bottombar', None, _('_Bottombar'),
              "<shift><PRIMARY>B", None, self.__bottombar_toggled,
              self.bottombar.get_property('visible'))
 
     def __build_action_group(self):
         """
         Create an UIManager ActionGroup from the values in self.action_list
-        and self.action_toggle_list. The user should define these in 
+        and self.action_toggle_list. The user should define these in
         self.define_actions
         """
         self.action_group = ActionGroup(name=self.title)
@@ -424,7 +457,7 @@ class PageView(DbGUIElement):
     def _add_action(self, name, icon_name, label, accel=None, tip=None,
                    callback=None):
         """
-        Add an action to the action list for the current view. 
+        Add an action to the action list for the current view.
         """
         self.action_list.append((name, icon_name, label, accel, tip,
                                  callback))
@@ -432,15 +465,15 @@ class PageView(DbGUIElement):
     def _add_toggle_action(self, name, icon_name, label, accel=None,
                            tip=None, callback=None, value=False):
         """
-        Add a toggle action to the action list for the current view. 
+        Add a toggle action to the action list for the current view.
         """
         self.action_toggle_list.append((name, icon_name, label, accel,
                                         tip, callback, value))
-    
-    def _add_toolmenu_action(self, name, label, tooltip, callback, 
+
+    def _add_toolmenu_action(self, name, label, tooltip, callback,
                              arrowtooltip):
         """
-        Add a menu action to the action list for the current view. 
+        Add a menu action to the action list for the current view.
         """
         self.action_toolmenu_list.append((name, label, tooltip, callback,
                                           arrowtooltip))
@@ -448,13 +481,13 @@ class PageView(DbGUIElement):
     def get_actions(self):
         """
         Return the actions that should be used for the view. This includes the
-        standard action group (which handles the main toolbar), along with 
+        standard action group (which handles the main toolbar), along with
         additional action groups.
 
-        If the action group is not defined, we build it the first time. This 
+        If the action group is not defined, we build it the first time. This
         allows us to delay the intialization until it is really needed.
 
-        The ViewManager uses this function to extract the actions to install 
+        The ViewManager uses this function to extract the actions to install
         into the UIManager.
         """
         if not self.action_group:
@@ -463,7 +496,7 @@ class PageView(DbGUIElement):
 
     def _add_action_group(self, group):
         """
-        Allows additional action groups to be added to the view. 
+        Allows additional action groups to be added to the view.
         """
         self.additional_action_groups.append(group)
 
@@ -473,40 +506,6 @@ class PageView(DbGUIElement):
         """
         self.uistate.clear_filter_results()
 
-    def edit(self, obj):
-        """
-        Template function to allow the editing of the selected object
-        """
-        raise NotImplementedError
-
-    def remove(self, handle):
-        """
-        Template function to allow the removal of an object by its handle
-        """
-        raise NotImplementedError
-
-    def remove_object_from_handle(self, handle):
-        """
-        Template function to allow the removal of an object by its handle
-        """
-        raise NotImplementedError
-
-    def add(self, obj):
-        """
-        Template function to allow the adding of a new object
-        """
-        raise NotImplementedError
-    
-    def _key_press(self, obj, event):
-        """
-        Define the action for a key press event
-        """
-        # TODO: This is never used? (replaced in ListView)
-        if event.keyval in (Gdk.KEY_Return, Gdk.KEY_KP_Enter):
-            self.edit(obj)
-            return True
-        return False
-
     def on_delete(self):
         """
         Method called on shutdown. Data views should put code here
@@ -518,21 +517,21 @@ class PageView(DbGUIElement):
 
     def init_config(self):
         """
-        If you need a view with a config, then call this method in the 
-        build_widget or __init__ method. It will set up a config file for the 
-        view, and use CONFIGSETTINGS to set the config defaults. 
+        If you need a view with a config, then call this method in the
+        build_widget or __init__ method. It will set up a config file for the
+        view, and use CONFIGSETTINGS to set the config defaults.
         The config is later accessbile via self._config
-        So you can do 
+        So you can do
         self._config.get("section.variable1")
         self._config.set("section.variable1", value)
         self._config.save()
-        
-        CONFIGSETTINGS should be a list with tuples like 
+
+        CONFIGSETTINGS should be a list with tuples like
         ("section.variable1", value)
         """
         if self._config:
             return
-        self._config = config.register_manager(self.ident, 
+        self._config = config.register_manager(self.ident,
                                                use_config_path=True)
         for section, value in self.CONFIGSETTINGS:
             self._config.register(section, value)
@@ -564,19 +563,19 @@ class PageView(DbGUIElement):
 
     def _get_configure_page_funcs(self):
         """
-        Return a list of functions that create gtk elements to use in the 
+        Return a list of functions that create gtk elements to use in the
         notebook pages of the Configure view
-        
+
         :return: list of functions
         """
-        raise NotImplementedError
+        return []
 
     def configure(self):
         """
         Open the configure dialog for the view.
         """
         title = _("Configure %(cat)s - %(view)s") % \
-                        {'cat': self.get_translated_category(), 
+                        {'cat': self.get_translated_category(),
                          'view': self.get_title()}
 
         if self.can_configure():
@@ -589,10 +588,10 @@ class PageView(DbGUIElement):
             config_funcs += self.bottombar.get_config_funcs()
 
         try:
-            ViewConfigureDialog(self.uistate, self.dbstate, 
+            ViewConfigureDialog(self.uistate, self.dbstate,
                             config_funcs,
                             self, self._config, dialogtitle=title,
-                            ident=_("%(cat)s - %(view)s") % 
+                            ident=_("%(cat)s - %(view)s") %
                                     {'cat': self.get_translated_category(),
                                      'view': self.get_title()})
         except WindowActiveError:
@@ -609,7 +608,8 @@ class ViewConfigureDialog(ConfigureDialog):
         ConfigureDialog.__init__(self, uistate, dbstate, configure_page_funcs,
                                  configobj, configmanager,
                                  dialogtitle=dialogtitle, on_close=on_close)
-        
+        self.setup_configs('interface.viewconfiguredialog', 420, 500)
+
     def build_menu_names(self, obj):
         return (_('Configure %s View') % self.ident, None)
 
@@ -621,7 +621,7 @@ class DummyPage(PageView):
         self.msg = msg1
         self.msg2 = msg2
         PageView.__init__(self, title, pdata, dbstate, uistate)
-    
+
     def build_widget(self):
         box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=1)
         #top widget at the top
