@@ -48,7 +48,7 @@ LOG = logging.getLogger(".ExportCSV")
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from gramps.gen.lib import EventType, Person
@@ -111,11 +111,12 @@ def get_primary_source_title(db, obj):
 class CSVWriterOptionBox(WriterOptionBox):
     """
     Create a VBox with the option widgets and define methods to retrieve
-    the options. 
-    
+    the options.
+
     """
-    def __init__(self, person, dbstate, uistate):
-        WriterOptionBox.__init__(self, person, dbstate, uistate)
+    def __init__(self, person, dbstate, uistate, track=[], window=None):
+        WriterOptionBox.__init__(self, person, dbstate, uistate, track=track,
+                                 window=window)
         ## TODO: add place filter selection
         self.include_individuals = 1
         self.include_marriages = 1
@@ -138,11 +139,11 @@ class CSVWriterOptionBox(WriterOptionBox):
         self.include_places_check = Gtk.CheckButton(label=_("Include places"))
         self.translate_headers_check = Gtk.CheckButton(label=_("Translate headers"))
 
-        self.include_individuals_check.set_active(1) 
-        self.include_marriages_check.set_active(1) 
-        self.include_children_check.set_active(1) 
-        self.include_places_check.set_active(1) 
-        self.translate_headers_check.set_active(1) 
+        self.include_individuals_check.set_active(1)
+        self.include_marriages_check.set_active(1)
+        self.include_children_check.set_active(1)
+        self.include_places_check.set_active(1)
+        self.translate_headers_check.set_active(1)
 
         option_box.pack_start(self.include_individuals_check, False, True, 0)
         option_box.pack_start(self.include_marriages_check, False, True, 0)
@@ -166,7 +167,7 @@ class CSVWriterOptionBox(WriterOptionBox):
 # CSVWriter class
 #
 #-------------------------------------------------------------------------
-class CSVWriter(object):
+class CSVWriter:
     def __init__(self, database, filename, user, option_box=None):
         self.db = database
         self.option_box = option_box
@@ -180,11 +181,11 @@ class CSVWriter(object):
         self.plist = {}
         self.flist = {}
         self.place_list = {}
-        
+
         self.persons_details_done = []
         self.persons_notes_done = []
         self.person_ids = {}
-        
+
         if not option_box:
             self.include_individuals = 1
             self.include_marriages = 1
@@ -200,7 +201,7 @@ class CSVWriter(object):
             self.include_children = self.option_box.include_children
             self.include_places = self.option_box.include_places
             self.translate_headers = self.option_box.translate_headers
-            
+
         self.plist = [x for x in self.db.iter_person_handles()]
 
         # make place list so that dependencies are first:
@@ -232,7 +233,7 @@ class CSVWriter(object):
                         child_handle = child_ref.ref
                         if child_handle in self.plist:
                             self.flist[family_handle] = 1
-                        
+
     def update_empty(self):
         pass
 
@@ -275,7 +276,7 @@ class CSVWriter(object):
             self.total += len(self.flist)
         if self.include_places:
             self.total += len(self.place_list)
-        ######################## 
+        ########################
         LOG.debug("Possible people to export: %s", len(self.plist))
         LOG.debug("Possible families to export: %s", len(self.flist))
         LOG.debug("Possible places to export: %s", len(self.place_list))
@@ -340,7 +341,7 @@ class CSVWriter(object):
                         "{count} dropped").format(
                             count=len(dropped_surnames)) )
             LOG.debug(
-                    "Dropped surnames: " + 
+                    "Dropped surnames: " +
                     ', '.join([("%s %s %s" % (surname.get_prefix(),
                     surname.get_surname(), surname.get_connector())).strip()
                     for surname in dropped_surnames]))
@@ -350,22 +351,22 @@ class CSVWriter(object):
         if self.include_individuals:
             if self.translate_headers:
                 self.write_csv(
-                    _("Person"), _("Surname"), _("Given"), 
-                    _("Call"), _("Suffix"), _("Prefix"), 
-                    _("Person|Title"), _("Gender"), 
+                    _("Person"), _("Surname"), _("Given"),
+                    _("Call"), _("Suffix"), _("Prefix"),
+                    _("Person|Title"), _("Gender"),
                     _("Birth date"), _("Birth place"), _("Birth source"),
                     _("Baptism date"), _("Baptism place"), _("Baptism source"),
-                    _("Death date"), _("Death place"), _("Death source"), 
+                    _("Death date"), _("Death place"), _("Death source"),
                     _("Burial date"), _("Burial place"), _("Burial source"),
                     _("Note"))
             else:
                 self.write_csv(
-                    "Person", "Surname", "Given", 
-                    "Call", "Suffix", "Prefix", 
-                    "Title", "Gender", 
+                    "Person", "Surname", "Given",
+                    "Call", "Suffix", "Prefix",
+                    "Title", "Gender",
                     "Birth date", "Birth place", "Birth source",
                     "Baptism date", "Baptism place", "Baptism source",
-                    "Death date", "Death place", "Death source", 
+                    "Death date", "Death place", "Death source",
                     "Burial date", "Burial place", "Burial source",
                     "Note")
             for key in plist:
@@ -400,9 +401,7 @@ class CSVWriter(object):
                         birth = self.db.get_event_from_handle(birth_ref.ref)
                         if birth:
                             birthdate = self.format_date( birth)
-                            place_handle = birth.get_place_handle()
-                            if place_handle:
-                                birthplace = _pd.display_event(self.db, birth)
+                            birthplace = self.format_place(birth)
                             birthsource = get_primary_source_title(self.db, birth)
                     # Baptism:
                     baptismdate = ""
@@ -414,9 +413,7 @@ class CSVWriter(object):
                         baptism = self.db.get_event_from_handle(baptism_ref.ref)
                         if baptism:
                             baptismdate = self.format_date( baptism)
-                            place_handle = baptism.get_place_handle()
-                            if place_handle:
-                                baptismplace = _pd.display_event(self.db, baptism)
+                            baptismplace = self.format_place(baptism)
                             baptismsource = get_primary_source_title(self.db, baptism)
                     # Death:
                     deathdate = ""
@@ -427,9 +424,7 @@ class CSVWriter(object):
                         death = self.db.get_event_from_handle(death_ref.ref)
                         if death:
                             deathdate = self.format_date( death)
-                            place_handle = death.get_place_handle()
-                            if place_handle:
-                                deathplace = _pd.display_event(self.db, death)
+                            deathplace = self.format_place(death)
                             deathsource = get_primary_source_title(self.db, death)
                     # Burial:
                     burialdate = ""
@@ -441,9 +436,7 @@ class CSVWriter(object):
                         burial = self.db.get_event_from_handle(burial_ref.ref)
                         if burial:
                             burialdate = self.format_date( burial)
-                            place_handle = burial.get_place_handle()
-                            if place_handle:
-                                burialplace = _pd.display_event(self.db, burial)
+                            burialplace = self.format_place(burial)
                             burialsource = get_primary_source_title(self.db, burial)
                     # Write it out:
                     self.write_csv(grampsid_ref, surname, first_name, callname,
@@ -466,13 +459,13 @@ class CSVWriter(object):
                     )
         sortorder.sort() # will sort on tuples
         flist = [data[1] for data in sortorder]
-        ########################### 
+        ###########################
         if self.include_marriages:
             if self.translate_headers:
-                self.write_csv(_("Marriage"), _("Husband"), _("Wife"), 
+                self.write_csv(_("Marriage"), _("Husband"), _("Wife"),
                                _("Date"), _("Place"), _("Source"), _("Note"))
             else:
-                self.write_csv("Marriage", "Husband", "Wife", 
+                self.write_csv("Marriage", "Husband", "Wife",
                                "Date", "Place", "Source", "Note")
             for key in flist:
                 family = self.db.get_family_from_handle(key)
@@ -501,10 +494,8 @@ class CSVWriter(object):
                         event = self.db.get_event_from_handle(event_ref.ref)
                         if event.get_type() == EventType.MARRIAGE:
                             mdate = self.format_date( event)
-                            place_handle = event.get_place_handle()
-                            if place_handle:
-                                mplace = _pd.display_event(self.db, event)
-                                source = get_primary_source_title(self.db, event)
+                            mplace = self.format_place(event)
+                            source = get_primary_source_title(self.db, event)
                     note = ''
                     self.write_csv(marriage_id, father_id, mother_id, mdate,
                                    mplace, source, note)
@@ -532,7 +523,22 @@ class CSVWriter(object):
                 self.update()
             self.writeln()
         self.fp.close()
-        return True 
-    
+        return True
+
     def format_date(self, date):
         return get_date(date)
+
+    def format_place(self, event):
+        """
+        If places are included in the export return a link, else return a
+        formatted place for the given event.
+        """
+        if self.include_places:
+            place_handle = event.get_place_handle()
+            if place_handle:
+                place = self.db.get_place_from_handle(place_handle)
+                if place:
+                    return "[%s]" % place.get_gramps_id()
+            return ""
+        else:
+            return _pd.display_event(self.db, event)
