@@ -3,7 +3,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2011-2012       Serge Noiraud
+# Copyright (C) 2011-2016       Serge Noiraud
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
 import re
-from gi.repository import GObject
 import math
 
 #------------------------------------------------------------------------
@@ -53,9 +52,12 @@ from gi.repository import Gtk
 #-------------------------------------------------------------------------
 from gramps.gen.errors import WindowActiveError
 from gramps.gui.managedwindow import ManagedWindow
+from gramps.gui.dialog import WarningDialog
 from .osmgps import OsmGps
 from gramps.gen.utils.location import get_main_location
 from gramps.gen.lib import PlaceType
+from gramps.gen.utils.place import conv_lat_lon
+from gramps.gen.display.place import displayer as _pd
 
 #-------------------------------------------------------------------------
 #
@@ -65,22 +67,8 @@ from gramps.gen.lib import PlaceType
 PLACE_REGEXP = re.compile('<span background="green">(.*)</span>')
 PLACE_STRING = '<span background="green">%s</span>'
 
-def match(self, lat, lon, radius):
-    """
-    coordinates matching.
-    """
-    rds = float(radius)
-    self.places = []
-
-    # place
-    for entry in self.place_list:
-        if (math.hypot(lat-float(entry[3]),
-                       lon-float(entry[4])) <= rds) == True:
-            # Do we already have this place ? avoid duplicates
-            country, state, county, place = self.get_location(entry[9])
-            if not [country, state, county, place] in self.places:
-                self.places.append([country, state, county, place])
-    return self.places
+# pylint: disable=unused-argument
+# pylint: disable=no-member
 
 #-------------------------------------------------------------------------
 #
@@ -103,8 +91,10 @@ class PlaceSelection(ManagedWindow, OsmGps):
             ManagedWindow.__init__(self, uistate, [], PlaceSelection)
         except WindowActiveError:
             return
+        OsmGps.__init__(self, uistate)
         self.uistate = uistate
         self.dbstate = dbstate
+        self.places = []
         self.lat = lat
         self.lon = lon
         self.osm = maps
@@ -115,8 +105,9 @@ class PlaceSelection(ManagedWindow, OsmGps):
         self.function = function
         self.selection_layer = layer
         self.layer = layer
+        self.warning = False
         self.set_window(
-            Gtk.Dialog(_('Place Selection in a region'),
+            Gtk.Dialog(_('Place Selection in a region'), uistate.window,
                        buttons=(_('_Close'), Gtk.ResponseType.CLOSE)),
             None, _('Place Selection in a region'), None)
         label = Gtk.Label(label=_('Choose the radius of the selection.\n'
@@ -137,19 +128,22 @@ class PlaceSelection(ManagedWindow, OsmGps):
         self.scroll = Gtk.ScrolledWindow(self.vadjust)
         self.scroll.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
         self.scroll.set_shadow_type(Gtk.ShadowType.IN)
-        self.plist = Gtk.ListStore(str, str, str, str)
+        self.plist = Gtk.ListStore(str, str, str, str, str)
         self.choices = Gtk.TreeView(self.plist)
         self.scroll.add(self.choices)
         self.renderer = Gtk.CellRendererText()
         self.tvcol1 = Gtk.TreeViewColumn(_('Country'), self.renderer, markup=0)
         self.tvcol2 = Gtk.TreeViewColumn(_('State'), self.renderer, markup=1)
         self.tvcol3 = Gtk.TreeViewColumn(_('County'), self.renderer, markup=2)
+        self.tvcol4 = Gtk.TreeViewColumn(_('Other'), self.renderer, markup=3)
         self.tvcol1.set_sort_column_id(0)
         self.tvcol2.set_sort_column_id(1)
         self.tvcol3.set_sort_column_id(2)
+        self.tvcol4.set_sort_column_id(3)
         self.choices.append_column(self.tvcol1)
         self.choices.append_column(self.tvcol2)
         self.choices.append_column(self.tvcol3)
+        self.choices.append_column(self.tvcol4)
         self.window.vbox.pack_start(self.scroll, True, True, 0)
         self.label2 = Gtk.Label()
         self.label2.set_markup('<span background="green" foreground="black"'
@@ -175,11 +169,12 @@ class PlaceSelection(ManagedWindow, OsmGps):
 
     def slider_change(self, obj, lat, lon):
         """
-        Display on the map a circle in which we select all the places inside this region.
+        Display on the map a circle in which we select all the places
+        inside this region.
         """
         self.radius = obj.get_value() if obj else 1.0
         self.show_the_region(self.radius)
-        match(self, lat, lon, self.radius)
+        self.match(lat, lon)
         self.plist.clear()
         if self.oldvalue != None:
             # The old values are always in the first row.
@@ -191,15 +186,17 @@ class PlaceSelection(ManagedWindow, OsmGps):
             self.plist.append((PLACE_STRING % loc.get(PlaceType.COUNTRY, ''),
                                PLACE_STRING % loc.get(PlaceType.STATE, ''),
                                PLACE_STRING % loc.get(PlaceType.COUNTY, ''),
+                               PLACE_STRING % _('Other'),
                                self.oldvalue)
                              )
         for place in self.places:
-            p = (place[0].value, place[1], place[2], place[3])
-            self.plist.append(p)
+            self.plist.append((place[0], place[1],
+                               place[2], place[3], place[4]))
         # here, we could add value from geography names services ...
 
         # if we found no place, we must create a default place.
-        self.plist.append((_("New place with empty fields"), "", "...", None))
+        self.plist.append((_("New place with empty fields"), "",
+                           "...", "", None))
 
     def hide_the_region(self):
         """
@@ -223,7 +220,7 @@ class PlaceSelection(ManagedWindow, OsmGps):
         get location values
         """
         parent_place = None
-        country = state = county = ''
+        country = state = county = other = ''
         place = self.dbstate.db.get_place_from_gramps_id(gramps_id)
         place_name = place.name.get_value()
         parent_list = place.get_placeref_list()
@@ -239,10 +236,64 @@ class PlaceSelection(ManagedWindow, OsmGps):
                 if parent_place is None:
                     parent_place = place.get_handle()
             elif int(place.get_type()) == PlaceType.COUNTRY:
-                country = place.name
+                country = place.name.get_value()
                 if parent_place is None:
                     parent_place = place.get_handle()
-        return(country, state, county, place_name)
+            else:
+                other = place.name.get_value()
+                if parent_place is None:
+                    parent_place = place.get_handle()
+        return(country, state, county, place_name, other)
+
+    def match(self, lat, lon):
+        """
+        coordinates matching.
+        """
+        rds = float(self.radius)
+        self.places = []
+
+        # place
+        for entry in self.place_list:
+            if (math.hypot(lat-float(entry[3]),
+                           lon-float(entry[4])) <= rds) == True:
+                # Do we already have this place ? avoid duplicates
+                (country, state, county,
+                 place, other) = self.get_location(entry[9])
+                if not [country, state, county, place, other] in self.places:
+                    self.places.append([country, state, county, place, other])
+        self.warning = False
+        for place in self.dbstate.db.iter_places():
+            latn = place.get_latitude()
+            lonn = place.get_longitude()
+            if latn and lonn:
+                latn, ignore = conv_lat_lon(latn, "0", "D.D8")
+                if not latn:
+                    if not self.warning:
+                        self.close()
+                    warn1 = _("you have a wrong latitude for:")
+                    warn2 = _pd.display(self.dbstate.db, place) + "\n\n<b>"
+                    warn2 += _("Please, correct this before linking") + "</b>"
+                    WarningDialog(warn1, warn2, parent=self.uistate.window)
+                    self.warning = True
+                    continue
+                ignore, lonn = conv_lat_lon("0", lonn, "D.D8")
+                if not lonn:
+                    if not self.warning:
+                        self.close()
+                    warn1 = _("you have a wrong longitude for:") + "\n"
+                    warn2 = _pd.display(self.dbstate.db, place) + "\n\n<b>"
+                    warn2 += _("Please, correct this before linking") + "</b>"
+                    WarningDialog(warn1, warn2, parent=self.uistate.window)
+                    self.warning = True
+                    continue
+                if (math.hypot(lat-float(latn),
+                               lon-float(lonn)) <= rds) == True:
+                    (country, state, county,
+                     place, other) = self.get_location(place.get_gramps_id())
+                    if not [country, state, county,
+                            place, other] in self.places:
+                        self.places.append([country, state, county,
+                                            place, other])
 
     def selection(self, obj, index, column, function):
         """
