@@ -44,12 +44,12 @@ from gi.repository import GdkPixbuf
 
 #------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #------------------------------------------------------------------------
 from gramps.gen.const import URL_MANUAL_PAGE, ICON, SPLASH
 from gramps.gui.display import display_help
-from gramps.gen.lib import MediaObject
+from gramps.gen.lib import Media
 from gramps.gen.db import DbTxn
 from gramps.gen.updatecallback import UpdateCallback
 from gramps.gui.plug import tool
@@ -57,6 +57,7 @@ from gramps.gen.utils.file import media_path_full, relative_path, media_path
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
 from gramps.gen.mime import get_type, is_image_type
+from gramps.gui.managedwindow import ManagedWindow
 
 #-------------------------------------------------------------------------
 #
@@ -71,47 +72,55 @@ WIKI_HELP_SEC = _('manual|Media_Manager...')
 # This is an Assistant implementation to guide the user
 #
 #-------------------------------------------------------------------------
-class MediaMan(tool.Tool):
+class MediaMan(ManagedWindow, tool.Tool):
 
     def __init__(self, dbstate, user, options_class, name, callback=None):
         uistate = user.uistate
 
         tool.Tool.__init__(self, dbstate, options_class, name)
-        self.uistate = uistate
+        ManagedWindow.__init__(self, uistate, [], self.__class__)
         self.callback = uistate.pulse_progressbar
 
         self.batch_ops = []
         self.build_batch_ops()
 
         self.assistant = Gtk.Assistant()
+        self.set_window(self.assistant, None, _('Media Manager'))
+        self.setup_configs('interface.mediaman', 780, 600)
 
-        self.assistant.set_title(_('Gramps Media Manager'))
-        self.assistant.connect('close', self.close)
-        self.assistant.connect('cancel', self.close)
+        self.assistant.connect('close', self.do_close)
+        self.assistant.connect('cancel', self.do_close)
         self.assistant.connect('apply', self.run)
         self.assistant.connect('prepare', self.prepare)
 
         intro = IntroductionPage()
         self.add_page(intro, Gtk.AssistantPageType.INTRO, _('Introduction'))
         self.selection = SelectionPage(self.batch_ops)
-        self.add_page(self.selection, Gtk.AssistantPageType.CONTENT, 
+        self.add_page(self.selection, Gtk.AssistantPageType.CONTENT,
                       _('Selection'))
         self.settings = SettingsPage(self.batch_ops, self.assistant)
         self.add_page(self.settings, Gtk.AssistantPageType.CONTENT)
         self.confirmation = ConfirmationPage(self.batch_ops)
-        self.add_page(self.confirmation, Gtk.AssistantPageType.CONFIRM, 
+        self.add_page(self.confirmation, Gtk.AssistantPageType.CONFIRM,
                       _('Final confirmation'))
         self.conclusion = ConclusionPage(self.assistant)
         self.add_page(self.conclusion, Gtk.AssistantPageType.SUMMARY)
-        
-        self.assistant.show()
+
+        self.show()
         self.assistant.set_forward_page_func(self.forward_page, None)
 
-    def close(self, assistant):
+    def build_menu_names(self, obj):
+        """Override :class:`.ManagedWindow` method."""
+        return (_('Media Manager'), None)
+
+    def do_close(self, assistant):
         """
         Close the assistant.
         """
+        position = self.window.get_position() # crock
         self.assistant.hide()
+        self.window.move(position[0], position[1])
+        self.close()
 
     def forward_page(self, page, data):
         """
@@ -173,7 +182,7 @@ class MediaMan(tool.Tool):
         success = self.batch_ops[index].run_tool()
         self.conclusion.set_result(success)
         self.post_run()
-        
+
     def pre_run(self):
         """
         Code to run prior to the batch op.
@@ -200,7 +209,7 @@ class IntroductionPage(Gtk.Box):
     def __init__(self):
         Gtk.Box.__init__(self, orientation=Gtk.Orientation.VERTICAL)
 
-        # Using set_page_side_image causes window sizing problems, so put the 
+        # Using set_page_side_image causes window sizing problems, so put the
         # image in the main page instead.
         image = Gtk.Image()
         image.set_from_file(SPLASH)
@@ -245,7 +254,7 @@ class SelectionPage(Gtk.Box):
     """
     def __init__(self, batch_ops):
         Gtk.Box.__init__(self, orientation=Gtk.Orientation.VERTICAL)
-        
+
         self.batch_op_buttons = []
 
         self.set_spacing(12)
@@ -253,7 +262,7 @@ class SelectionPage(Gtk.Box):
         grid = Gtk.Grid()
         grid.set_row_spacing(6)
         grid.set_column_spacing(6)
-        
+
         button = None
         for index in range(len(batch_ops)):
             title = batch_ops[index].title
@@ -263,20 +272,20 @@ class SelectionPage(Gtk.Box):
             button.set_tooltip_text(description)
             self.batch_op_buttons.append(button)
             grid.attach(button, 0, 2 * index, 2, 1)
-        
+
         self.add(grid)
 
     def get_index(self):
         """
-        Query the selection radiobuttons and return the index number 
-        of the selected batch op. 
+        Query the selection radiobuttons and return the index number
+        of the selected batch op.
         """
         for index in range(len(self.batch_op_buttons)):
             button = self.batch_op_buttons[index]
             if button.get_active():
                 return index
-        else:
-            return 0
+
+        return 0
 
 class SettingsPage(Gtk.Box):
     """
@@ -305,7 +314,7 @@ class SettingsPage(Gtk.Box):
 
 class ConfirmationPage(Gtk.Box):
     """
-    A page to display the summary of the proposed action, as well as the 
+    A page to display the summary of the proposed action, as well as the
     list of affected paths.
     """
     def __init__(self, batch_ops):
@@ -354,7 +363,7 @@ class ConfirmationPage(Gtk.Box):
 
 class ConclusionPage(Gtk.Box):
     """
-    A page to display the summary of the proposed action, as well as the 
+    A page to display the summary of the proposed action, as well as the
     list of affected paths.
     """
     def __init__(self, assistant):
@@ -370,7 +379,7 @@ class ConclusionPage(Gtk.Box):
 
         self.pack_start(image, False, False, 0)
         self.pack_start(self.label, False, False, 5)
-        
+
     def set_result(self, success):
         if success:
             conclusion_title =  _('Operation successfully finished')
@@ -491,7 +500,7 @@ class PathChange(BatchOp):
         self.from_entry = Gtk.Entry()
         self.from_entry.set_hexpand(True)
         grid.attach(self.from_entry, 1, 0, 1, 1)
-        
+
         from_label = Gtk.Label(label=_('_Replace:'))
         from_label.set_halign(Gtk.Align.START)
         from_label.set_use_underline(True)
@@ -520,17 +529,17 @@ class PathChange(BatchOp):
             'Operation:\t%(title)s\n'
             'Replace:\t\t%(src_fname)s\n'
             'With:\t\t%(dest_fname)s') % {
-            'title' : self.title.replace('_',''), 
-            'src_fname' : from_text, 
+            'title' : self.title.replace('_',''),
+            'src_fname' : from_text,
             'dest_fname' : to_text }
         return text
-        
+
     def _prepare(self):
         from_text = str(self.from_entry.get_text())
-        self.set_total(self.db.get_number_of_media_objects())
+        self.set_total(self.db.get_number_of_media())
         with self.db.get_media_cursor() as cursor:
             for handle, data in cursor:
-                obj = MediaObject()
+                obj = Media()
                 obj.unserialize(data)
                 if obj.get_path().find(from_text) != -1:
                     self.handle_list.append(handle)
@@ -546,10 +555,10 @@ class PathChange(BatchOp):
         from_text = str(self.from_entry.get_text())
         to_text = str(self.to_entry.get_text())
         for handle in self.handle_list:
-            obj = self.db.get_object_from_handle(handle)
+            obj = self.db.get_media_from_handle(handle)
             new_path = obj.get_path().replace(from_text, to_text)
             obj.set_path(new_path)
-            self.db.commit_media_object(obj, self.trans)
+            self.db.commit_media(obj, self.trans)
             self.update()
         return True
 
@@ -564,10 +573,10 @@ class Convert2Abs(BatchOp):
                     "that is not set, it prepends user's directory.")
 
     def _prepare(self):
-        self.set_total(self.db.get_number_of_media_objects())
+        self.set_total(self.db.get_number_of_media())
         with self.db.get_media_cursor() as cursor:
             for handle, data in cursor:
-                obj = MediaObject()
+                obj = Media()
                 obj.unserialize(data)
                 if not os.path.isabs(obj.path):
                     self.handle_list.append(handle)
@@ -580,10 +589,10 @@ class Convert2Abs(BatchOp):
             self.prepare()
         self.set_total(len(self.handle_list))
         for handle in self.handle_list:
-            obj = self.db.get_object_from_handle(handle)
+            obj = self.db.get_media_from_handle(handle)
             new_path = media_path_full(self.db, obj.path)
             obj.set_path(new_path)
-            self.db.commit_media_object(obj, self.trans)
+            self.db.commit_media(obj, self.trans)
             self.update()
         return True
 
@@ -600,10 +609,10 @@ class Convert2Rel(BatchOp):
                     "a base path that can change to your needs.")
 
     def _prepare(self):
-        self.set_total(self.db.get_number_of_media_objects())
+        self.set_total(self.db.get_number_of_media())
         with self.db.get_media_cursor() as cursor:
             for handle, data in cursor:
-                obj = MediaObject()
+                obj = Media()
                 obj.unserialize(data)
                 if os.path.isabs(obj.path):
                     self.handle_list.append(handle)
@@ -617,10 +626,10 @@ class Convert2Rel(BatchOp):
         self.set_total(len(self.handle_list))
         base_dir = media_path(self.db)
         for handle in self.handle_list:
-            obj = self.db.get_object_from_handle(handle)
+            obj = self.db.get_media_from_handle(handle)
             new_path = relative_path(obj.path, base_dir)
             obj.set_path(new_path)
-            self.db.commit_media_object(obj, self.trans)
+            self.db.commit_media(obj, self.trans)
             self.update()
         return True
 
@@ -639,10 +648,10 @@ class ImagesNotIncluded(BatchOp):
         objects in the database.
         """
         self.dir_list = set()
-        self.set_total(self.db.get_number_of_media_objects())
+        self.set_total(self.db.get_number_of_media())
         with self.db.get_media_cursor() as cursor:
             for handle, data in cursor:
-                obj = MediaObject()
+                obj = Media()
                 obj.unserialize(data)
                 self.handle_list.append(handle)
                 full_path = media_path_full(self.db, obj.path)
@@ -681,18 +690,18 @@ class ImagesNotIncluded(BatchOp):
                         self.path_list.append(media_full_path)
                         mime_type = get_type(media_full_path)
                         if is_image_type(mime_type):
-                            obj = MediaObject()
+                            obj = Media()
                             obj.set_path(media_full_path)
                             obj.set_mime_type(mime_type)
                             (root, ext) = os.path.splitext(filename)
                             obj.set_description(root)
-                            self.db.add_object(obj, self.trans)
+                            self.db.add_media(obj, self.trans)
             self.update()
         return True
 
 #------------------------------------------------------------------------
 #
-# 
+#
 #
 #------------------------------------------------------------------------
 class MediaManOptions(tool.ToolOptions):
