@@ -3,7 +3,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2011  Serge Noiraud
+# Copyright (C) 2011-2016  Serge Noiraud
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.gettext
 import operator
 from gi.repository import Gtk
-from math import *
+from math import hypot
 from html import escape
 
 #-------------------------------------------------------------------------
@@ -93,8 +93,8 @@ _UI_DEF = '''\
 </menubar>
 <toolbar name="ToolBar">
 <placeholder name="CommonNavigation">
-  <toolitem action="Back"/>  
-  <toolitem action="Forward"/>  
+  <toolitem action="Back"/>
+  <toolitem action="Forward"/>
   <toolitem action="HomePerson"/>
   <toolitem action="RefPerson"/>
 </placeholder>
@@ -105,6 +105,9 @@ _UI_DEF = '''\
 </ui>
 '''
 
+# pylint: disable=no-member
+# pylint: disable=unused-argument
+
 #-------------------------------------------------------------------------
 #
 # GeoView
@@ -138,7 +141,7 @@ class GeoClose(GeoGraphyView):
 
     def __init__(self, pdata, dbstate, uistate, nav_group=0):
         GeoGraphyView.__init__(self, _("Have they been able to meet?"),
-                                      pdata, dbstate, uistate, 
+                                      pdata, dbstate, uistate,
                                       PersonBookmarks,
                                       nav_group)
         self.dbstate = dbstate
@@ -163,6 +166,9 @@ class GeoClose(GeoGraphyView):
         self.place_list_ref = []
         self.cal = config.get('preferences.calendar-format-report')
         self.no_show_places_in_status_bar = False
+        self.add_item = None
+        self.newmenu = None
+        self.config_meeting_slider = None
 
     def get_title(self):
         """
@@ -173,11 +179,11 @@ class GeoClose(GeoGraphyView):
     def get_stock(self):
         """
         Returns the name of the stock icon to use for the display.
-        This assumes that this icon has already been registered 
+        This assumes that this icon has already been registered
         as a stock icon.
         """
         return 'gramps-relation'
-    
+
     def get_viewtype_stock(self):
         """Type of view in category
         """
@@ -215,20 +221,22 @@ class GeoClose(GeoGraphyView):
         self.message_layer.clear_messages()
         active = self.get_active()
         if active:
-            p1 = self.dbstate.db.get_person_from_handle(active)
+            indiv1 = self.dbstate.db.get_person_from_handle(active)
             color = self._config.get('geography.color2')
-            self._createmap(p1, color, self.place_list_active, False)
+            self._createmap(indiv1, color, self.place_list_active, False)
         if self.refperson:
             color = self._config.get('geography.color1')
-            self.message_layer.add_message(_("Reference : %(name)s ( %(birth)s - %(death)s )") % {
-                                                           'name': _nd.display(self.refperson),
-                                                           'birth': self.birth(self.refperson),
-                                                           'death': self.death(self.refperson)})
-            if p1:
-                self.message_layer.add_message(_("The other : %(name)s ( %(birth)s - %(death)s )") % {
-                                                               'name': _nd.display(p1),
-                                                               'birth': self.birth(p1),
-                                                               'death': self.death(p1)})
+            self.message_layer.add_message(
+                         _("Reference : %(name)s ( %(birth)s - %(death)s )") % {
+                                 'name': _nd.display(self.refperson),
+                                 'birth': self.birth(self.refperson),
+                                 'death': self.death(self.refperson)})
+            if indiv1:
+                self.message_layer.add_message(
+                         _("The other : %(name)s ( %(birth)s - %(death)s )") % {
+                                 'name': _nd.display(indiv1),
+                                 'birth': self.birth(indiv1),
+                                 'death': self.death(indiv1)})
             else:
                 self.message_layer.add_message(_("The other person is unknown"))
             self._createmap(self.refperson, color, self.place_list_ref, True)
@@ -236,10 +244,12 @@ class GeoClose(GeoGraphyView):
                 self.refperson_bookmark = self.refperson.get_handle()
                 self.add_bookmark_from_popup(None, self.refperson_bookmark)
         else:
-            self.message_layer.add_message(_("You must choose one reference person."))
+            self.message_layer.add_message(
+                                     _("You must choose one reference person."))
             self.message_layer.add_message(_("Go to the person view and select "
                                              "the people you want to compare. "
-                                             "Return to this view and use the history."))
+                                             "Return to this view and use the"
+                                             " history."))
         self.possible_meeting(self.place_list_ref, self.place_list_active)
         self.uistate.modify_statusbar(self.dbstate)
 
@@ -286,13 +296,13 @@ class GeoClose(GeoGraphyView):
         self.define_print_actions()
         self.ref_person = Gtk.ActionGroup(name=self.title + '/Selection')
         self.ref_person.add_actions([
-            ('RefPerson', 'gramps-person', _('reference _Person'), None ,
+            ('RefPerson', 'gramps-person', _('reference _Person'), None,
             _("Select the person which is the reference for life ways"),
-            self.selectPerson),
+            self.select_person),
             ])
         self._add_action_group(self.ref_person)
 
-    def selectPerson(self, obj):
+    def select_person(self, obj):
         """
         Open a selection box to choose the ref person.
         """
@@ -300,8 +310,8 @@ class GeoClose(GeoGraphyView):
         self.skip_list = []
         self.refperson = None
         self.refperson_bookmark = None
-        SelectPerson = SelectorFactory('Person')
-        sel = SelectPerson(self.dbstate, self.uistate, self.track,
+        selectperson = SelectorFactory('Person')
+        sel = selectperson(self.dbstate, self.uistate, self.track,
                            _("Select the person which will be our reference."),
                            skip=self.skip_list)
         self.refperson = sel.run()
@@ -313,13 +323,18 @@ class GeoClose(GeoGraphyView):
         all handling of visibility is now in rebuild_trees, see that for more
         information.
         """
-        active = self.get_active()
-        person = self.dbstate.db.get_person_from_handle(active)
         self.lifeway_layer.clear_ways()
-        if person is None:
-            self.goto_handle(None)
+        if not self.dbstate.is_open():
+            return
+        active = self.get_active()
+        if active:
+            person = self.dbstate.db.get_person_from_handle(active)
+            if person is None:
+                self.goto_handle(None)
+            else:
+                self.goto_handle(handle=person)
         else:
-            self.goto_handle(handle=person)
+            self.goto_handle(None)
 
     def draw(self, menu, marks, color, reference):
         """
@@ -339,7 +354,7 @@ class GeoClose(GeoGraphyView):
         self.lifeway_layer.add_way(points, color)
         if reference:
             self.lifeway_layer.add_way_ref(points, 'orange',
-                     float(self._config.get("geography.maximum_meeting_zone")) / 10)
+                 float(self._config.get("geography.maximum_meeting_zone")) / 10)
         return False
 
     def possible_meeting(self, place_list_ref, place_list_active):
@@ -360,7 +375,7 @@ class GeoClose(GeoGraphyView):
 
     def _createmap(self, person, color, place_list, reference):
         """
-        Create all markers for each people's event in the database which has 
+        Create all markers for each people's event in the database which has
         a lat/lon.
         """
         dbstate = self.dbstate
@@ -402,7 +417,7 @@ class GeoClose(GeoGraphyView):
                         # place.get_longitude and place.get_latitude return
                         # one string. We have coordinates when the two values
                         # contains non null string.
-                        if ( longitude and latitude ):
+                        if longitude and latitude:
                             self._append_to_places_list(descr, evt,
                                                         _nd.display(person),
                                                         latitude, longitude,
@@ -448,12 +463,12 @@ class GeoClose(GeoGraphyView):
                                         latitude, longitude = conv_lat_lon(
                                                   latitude, longitude, "D.D8")
                                         descr = _pd.display(dbstate.db, place)
-                                        evt = EventType(
-                                                  event.get_type())
-                                        eyear = str("%04d" % event.get_date_object().to_calendar(self.cal).get_year()) + \
-                                                  str("%02d" % event.get_date_object().to_calendar(self.cal).get_month()) + \
-                                                  str("%02d" % event.get_date_object().to_calendar(self.cal).get_day())
-                                        if ( longitude and latitude ):
+                                        evt = EventType(event.get_type())
+                                        eyear = str(
+         "%04d" % event.get_date_object().to_calendar(self.cal).get_year()) + \
+     str("%02d" % event.get_date_object().to_calendar(self.cal).get_month()) + \
+     str("%02d" % event.get_date_object().to_calendar(self.cal).get_day())
+                                        if longitude and latitude:
                                             self._append_to_places_list(descr,
                                                  evt, _nd.display(person),
                                                  latitude, longitude,
@@ -465,13 +480,14 @@ class GeoClose(GeoGraphyView):
                                                  role
                                                  )
                                         else:
-                                            self._append_to_places_without_coord( place.gramps_id, descr)
+                                            self._append_to_places_without_coord(place.gramps_id, descr)
 
             sort1 = sorted(self.place_list, key=operator.itemgetter(6))
             self.draw(None, sort1, color, reference)
             # merge with the last results
             merge_list = []
-            for the_list in self.sort, sort1 : merge_list += the_list
+            for the_list in self.sort, sort1:
+                merge_list += the_list
             self.sort = sorted(merge_list, key=operator.itemgetter(6))
 
     def bubble_message(self, event, lat, lon, marks):
@@ -487,12 +503,12 @@ class GeoClose(GeoGraphyView):
         prevmark = None
         for mark in marks:
             for plce in self.all_place_list:
-                if (plce[3] == mark[3] and plce[4] == mark[4]):
+                if plce[3] == mark[3] and plce[4] == mark[4]:
                     if plce[10] in events:
                         continue
                     else:
                         events.append(plce[10])
-                      
+
                     if plce[0] != oldplace:
                         message = "%s :" % plce[0]
                         self.add_place_bubble_message(event, lat, lon,
@@ -505,18 +521,19 @@ class GeoClose(GeoGraphyView):
                     date = displayer.display(evt.get_date_object())
                     if date == "":
                         date = _("Unknown")
-                    if ( plce[11] == EventRoleType.PRIMARY ):
-                        message = "(%s) %s : %s" % ( date, plce[2], plce[1] )
-                    elif ( plce[11] == EventRoleType.FAMILY ):
-                        (father_name, mother_name) = self._get_father_and_mother_name(evt)
+                    if plce[11] == EventRoleType.PRIMARY:
+                        message = "(%s) %s : %s" % (date, plce[2], plce[1])
+                    elif plce[11] == EventRoleType.FAMILY:
+                        (father_name,
+                         mother_name) = self._get_father_and_mother_name(evt)
                         message = "(%s) %s : %s - %s" % (date, plce[7],
                                                          father_name,
-                                                         mother_name )
+                                                         mother_name)
                     else:
                         descr = evt.get_description()
                         if descr == "":
                             descr = _('No description')
-                        message = "(%s) %s => %s" % ( date, plce[11], descr)
+                        message = "(%s) %s => %s" % (date, plce[11], descr)
                     prevmark = plce
                     self.add_item = Gtk.MenuItem(label=message)
                     add_item = self.add_item
@@ -542,15 +559,16 @@ class GeoClose(GeoGraphyView):
                                None, event.button, event.time)
         return 0
 
-    def add_specific_menu(self, menu, event, lat, lon): 
-        """ 
+    def add_specific_menu(self, menu, event, lat, lon):
+        """
         Add specific entry to the navigation menu.
-        """ 
+        """
         add_item = Gtk.MenuItem()
         add_item.show()
         menu.append(add_item)
-        add_item = Gtk.MenuItem(label=_("Choose and bookmark the new reference person"))
-        add_item.connect("activate", self.selectPerson)
+        add_item = Gtk.MenuItem(
+                        label=_("Choose and bookmark the new reference person"))
+        add_item.connect("activate", self.select_person)
         add_item.show()
         menu.append(add_item)
         return
@@ -580,7 +598,7 @@ class GeoClose(GeoGraphyView):
                   'The value is in tenth of degree.'),
                 1, line_wrap=False)
         self.config_meeting_slider = configdialog.add_slider(grid,
-                "", 
+                "",
                 2, 'geography.maximum_meeting_zone',
                 (1, 9))
         return _('The selection parameters'), grid
