@@ -3,7 +3,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2011  Serge Noiraud
+# Copyright (C) 2011-2016  Serge Noiraud
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,12 +28,9 @@ Geography for one family
 # Python modules
 #
 #-------------------------------------------------------------------------
-import os
-import sys
 import operator
 from gi.repository import Gdk
 KEY_TAB = Gdk.KEY_Tab
-import socket
 from gi.repository import Gtk
 
 #-------------------------------------------------------------------------
@@ -57,11 +54,6 @@ from gramps.gen.datehandler import displayer
 from gramps.gen.display.name import displayer as _nd
 from gramps.gen.display.place import displayer as _pd
 from gramps.gen.utils.place import conv_lat_lon
-from gramps.gui.views.pageview import PageView
-from gramps.gui.editors import EditPlace
-from gramps.gui.selectors.selectplace import SelectPlace
-from gramps.gui.filters.sidebar import FamilySidebarFilter
-from gramps.gui.views.navigationview import NavigationView
 from gramps.gui.views.bookmarks import FamilyBookmarks
 from gramps.plugins.lib.maps.geography import GeoGraphyView
 
@@ -95,8 +87,8 @@ _UI_DEF = '''\
 </menubar>
 <toolbar name="ToolBar">
 <placeholder name="CommonNavigation">
-  <toolitem action="Back"/>  
-  <toolitem action="Forward"/>  
+  <toolitem action="Back"/>
+  <toolitem action="Forward"/>
 </placeholder>
 <placeholder name="CommonEdit">
   <toolitem action="PrintView"/>
@@ -105,6 +97,10 @@ _UI_DEF = '''\
 </ui>
 '''
 
+# pylint: disable=no-member
+# pylint: disable=unused-variable
+# pylint: disable=unused-argument
+
 #-------------------------------------------------------------------------
 #
 # GeoView
@@ -112,12 +108,12 @@ _UI_DEF = '''\
 #-------------------------------------------------------------------------
 class GeoFamily(GeoGraphyView):
     """
-    The view used to render person map.
+    The view used to render family map.
     """
 
     def __init__(self, pdata, dbstate, uistate, nav_group=0):
         GeoGraphyView.__init__(self, _('Family places map'),
-                                      pdata, dbstate, uistate, 
+                                      pdata, dbstate, uistate,
                                       FamilyBookmarks,
                                       nav_group)
         self.dbstate = dbstate
@@ -132,6 +128,7 @@ class GeoFamily(GeoGraphyView):
         self.sort = []
         self.additional_uis.append(self.additional_ui())
         self.no_show_places_in_status_bar = False
+        self.cal = None
 
     def get_title(self):
         """
@@ -142,11 +139,11 @@ class GeoFamily(GeoGraphyView):
     def get_stock(self):
         """
         Returns the name of the stock icon to use for the display.
-        This assumes that this icon has already been registered 
+        This assumes that this icon has already been registered
         as a stock icon.
         """
         return 'geo-show-family'
-    
+
     def get_viewtype_stock(self):
         """Type of view in category
         """
@@ -178,6 +175,8 @@ class GeoFamily(GeoGraphyView):
         all handling of visibility is now in rebuild_trees, see that for more
         information.
         """
+        if not self.dbstate.is_open():
+            return
         if self.uistate.get_active('Family'):
             self._createmap(self.uistate.get_active('Family'))
         else:
@@ -213,8 +212,9 @@ class GeoFamily(GeoGraphyView):
                         # place.get_longitude and place.get_latitude return
                         # one string. We have coordinates when the two values
                         # contains non null string.
-                        if ( longitude and latitude ):
-                            if not self._present_in_places_list(2, str(descr1 + descr + str(evt))):
+                        if longitude and latitude:
+                            if not self._present_in_places_list(2,
+                                                str(descr1 + descr + str(evt))):
                                 self._append_to_places_list(descr,
                                     str(descr1 + descr + str(evt)),
                                     _nd.display(person),
@@ -235,60 +235,74 @@ class GeoFamily(GeoGraphyView):
                 if family is not None:
                     for event_ref in family.get_event_ref_list():
                         if event_ref:
-                            event = dbstate.db.get_event_from_handle(event_ref.ref)
+                            event = dbstate.db.get_event_from_handle(
+                                                                  event_ref.ref)
                             role = event_ref.get_role()
                             if event.get_place_handle():
                                 place_handle = event.get_place_handle()
                                 if place_handle:
-                                    place = dbstate.db.get_place_from_handle(place_handle)
+                                    place = dbstate.db.get_place_from_handle(
+                                                                   place_handle)
                                     if place:
                                         longitude = place.get_longitude()
                                         latitude = place.get_latitude()
-                                        latitude, longitude = conv_lat_lon(latitude,
-                                                                           longitude, "D.D8")
+                                        (latitude,
+                                         longitude) = conv_lat_lon(latitude,
+                                                                   longitude,
+                                                                   "D.D8")
                                         descr = _pd.display(dbstate.db, place)
                                         evt = EventType(event.get_type())
-                                        (father_name, mother_name) = self._get_father_and_mother_name(event)
-                                        descr1 = "%s : %s - " % ( evt, father_name )
-                                        descr1 = "%s%s" % ( descr1, mother_name )
+                                        (father_name,
+                          mother_name) = self._get_father_and_mother_name(event)
+                                        descr1 = "%s : %s - " % (evt,
+                                                                 father_name)
+                                        descr1 = "%s%s" % (descr1, mother_name)
                                         eyear = event.get_date_object().to_calendar(self.cal).get_year()
-                                        if ( longitude and latitude ):
-                                            if not self._present_in_places_list(2, str(descr1 + descr + str(evt))):
-                                                self._append_to_places_list(descr,
-                                                    str(descr1 + descr + str(evt)),
-                                                    _nd.display(person),
-                                                    latitude, longitude,
-                                                    role, eyear,
-                                                    event.get_type(),
-                                                    person.gramps_id,
-                                                    place.gramps_id,
-                                                    event.gramps_id,
-                                                    family.gramps_id
-                                                    )
+                                        if longitude and latitude:
+                                            if not self._present_in_places_list(
+                                             2, str(descr1 + descr + str(evt))):
+                                                self._append_to_places_list(
+                                                 descr,
+                                                 str(descr1 + descr + str(evt)),
+                                                 _nd.display(person),
+                                                 latitude, longitude,
+                                                 role, eyear,
+                                                 event.get_type(),
+                                                 person.gramps_id,
+                                                 place.gramps_id,
+                                                 event.gramps_id,
+                                                 family.gramps_id
+                                                 )
                                         else:
-                                            self._append_to_places_without_coord( place.gramps_id, descr)
+                                            self._append_to_places_without_coord(place.gramps_id, descr)
 
-    def family_label(self,family):
+    def family_label(self, family):
+        """
+        Create the family label depending on existence of the father and mother
+        """
         if family is None:
             return "Unknown"
-        f = self.dbstate.db.get_person_from_handle(
-            family.get_father_handle())
-        m = self.dbstate.db.get_person_from_handle(
-            family.get_mother_handle())
-        if f and m:
+        father = mother = None
+        hdl = family.get_father_handle()
+        if hdl:
+            father = self.dbstate.db.get_person_from_handle(hdl)
+        hdl = family.get_mother_handle()
+        if hdl:
+            mother = self.dbstate.db.get_person_from_handle(hdl)
+        if father and mother:
             label = _("%(gramps_id)s : %(father)s and %(mother)s") % {
-                'father' : _nd.display(f),
-                'mother' : _nd.display(m),
+                'father' : _nd.display(father),
+                'mother' : _nd.display(mother),
                 'gramps_id' : family.gramps_id,
                 }
-        elif f:
+        elif father:
             label = "%(gramps_id)s : %(father)s" % {
-                'father' : _nd.display(f),
+                'father' : _nd.display(father),
                 'gramps_id' : family.gramps_id,
                 }
-        elif m:
+        elif mother:
             label = "%(gramps_id)s : %(mother)s" % {
-                'mother' : _nd.display(m),
+                'mother' : _nd.display(mother),
                 'gramps_id' : family.gramps_id,
                 }
         else:
@@ -297,39 +311,51 @@ class GeoFamily(GeoGraphyView):
                 'gramps_id' : family.gramps_id,
                 }
         return label
- 
+
     def _createmap_for_one_family(self, family):
         """
         Create all markers for one family : all event's places with a lat/lon.
         """
         dbstate = self.dbstate
-        self.message_layer.add_message(_("Family places for %s") % self.family_label(family))
-        try:
-            person = dbstate.db.get_person_from_handle(family.get_father_handle())
-        except:
+        self.message_layer.add_message(
+                          _("Family places for %s") % self.family_label(family))
+        person = None
+        if family:
+            person = dbstate.db.get_person_from_handle(
+                                                     family.get_father_handle())
+        else:
             return
         family_id = family.gramps_id
         if person is None: # family without father ?
-            person = dbstate.db.get_person_from_handle(family.get_mother_handle())
+            handle = family.get_mother_handle()
+            if handle:
+                person = dbstate.db.get_person_from_handle(handle)
         if person is None:
-            person = dbstate.db.get_person_from_handle(self.uistate.get_active('Person'))
+            handle = self.uistate.get_active('Person')
+            if handle:
+                person = dbstate.db.get_person_from_handle(handle)
         if person is not None:
             family_list = person.get_family_handle_list()
             if len(family_list) > 0:
                 fhandle = family_list[0] # first is primary
                 fam = dbstate.db.get_family_from_handle(fhandle)
+                father = mother = None
                 handle = fam.get_father_handle()
-                father = dbstate.db.get_person_from_handle(handle)
+                if handle:
+                    father = dbstate.db.get_person_from_handle(handle)
                 if father:
-                    comment = _("Father : %(id)s : %(name)s") % {'id': father.gramps_id,
-                                                        'name': _nd.display(father) }
+                    comment = _("Father : %(id)s : %(name)s") % {
+                                                   'id': father.gramps_id,
+                                                   'name': _nd.display(father)}
                     self._createpersonmarkers(dbstate, father,
                                               comment, family_id)
                 handle = fam.get_mother_handle()
-                mother = dbstate.db.get_person_from_handle(handle)
+                if handle:
+                    mother = dbstate.db.get_person_from_handle(handle)
                 if mother:
-                    comment = _("Mother : %(id)s : %(name)s") % {'id': mother.gramps_id,
-                                                        'name': _nd.display(mother) }
+                    comment = _("Mother : %(id)s : %(name)s") % {
+                                                   'id': mother.gramps_id,
+                                                   'name': _nd.display(mother)}
                     self._createpersonmarkers(dbstate, mother,
                                               comment, family_id)
                 index = 0
@@ -349,16 +375,18 @@ class GeoFamily(GeoGraphyView):
                                                       comment, family_id)
             else:
                 comment = _("Person : %(id)s %(name)s has no family.") % {
-                                'id' : person.gramps_id ,
+                                'id' : person.gramps_id,
                                 'name' : _nd.display(person)
                                 }
                 self._createpersonmarkers(dbstate, person, comment, family_id)
 
-    def _createmap(self, family_x):
+    def _createmap(self, handle):
         """
-        Create all markers for each people's event in the database which has 
+        Create all markers for each people's event in the database which has
         a lat/lon.
         """
+        if not handle:
+            return
         self.place_list = []
         self.place_without_coordinates = []
         self.places_found = []
@@ -368,9 +396,11 @@ class GeoFamily(GeoGraphyView):
         self.minyear = 9999
         self.maxyear = 0
         self.message_layer.clear_messages()
-        family = self.dbstate.db.get_family_from_handle(family_x)
-        if family is None:
-            person = self.dbstate.db.get_person_from_handle(self.uistate.get_active('Person'))
+        if self.dbstate.db.has_family_handle(handle):
+            family = self.dbstate.db.get_family_from_handle(handle)
+            self._createmap_for_one_family(family)
+        else:
+            person = self.dbstate.db.get_person_from_handle(handle)
             if not person:
                 return
             family_list = person.get_family_handle_list()
@@ -378,14 +408,15 @@ class GeoFamily(GeoGraphyView):
                 family = self.dbstate.db.get_family_from_handle(family_hdl)
                 if family is not None:
                     self._createmap_for_one_family(family)
-        else:
-            self._createmap_for_one_family(family)
         self.sort = sorted(self.place_list,
                            key=operator.itemgetter(3, 4, 6)
                           )
         self._create_markers()
 
     def add_event_bubble_message(self, event, lat, lon, mark, menu):
+        """
+        Add an item to the popup menu.
+        """
         self.itemoption = Gtk.Menu()
         itemoption = self.itemoption
         itemoption.show()
@@ -408,6 +439,9 @@ class GeoFamily(GeoGraphyView):
         itemoption.append(center)
 
     def bubble_message(self, event, lat, lon, marks):
+        """
+        Add the popup menu.
+        """
         self.menu = Gtk.Menu()
         menu = self.menu
         menu.set_title("family")
@@ -431,18 +465,20 @@ class GeoFamily(GeoGraphyView):
             date = displayer.display(evt.get_date_object())
             if date == "":
                 date = _("Unknown")
-            if ( mark[5] == EventRoleType.PRIMARY ):
-                message = "(%s) %s : %s" % ( date, mark[7], mark[1] )
-            elif ( mark[5] == EventRoleType.FAMILY ):
+            if mark[5] == EventRoleType.PRIMARY:
+                message = "(%s) %s : %s" % (date, mark[7], mark[1])
+            elif mark[5] == EventRoleType.FAMILY:
                 evt = self.dbstate.db.get_event_from_gramps_id(mark[10])
-                (father_name, mother_name) = self._get_father_and_mother_name(evt)
-                message = "(%s) %s : %s - %s" % ( date, mark[7], father_name, mother_name )
+                (father_name,
+                 mother_name) = self._get_father_and_mother_name(evt)
+                message = "(%s) %s : %s - %s" % (date, mark[7],
+                                                 father_name, mother_name)
             else:
                 evt = self.dbstate.db.get_event_from_gramps_id(mark[10])
                 descr = evt.get_description()
                 if descr == "":
                     descr = _('No description')
-                message = "(%s) %s => %s" % ( date, mark[5], descr)
+                message = "(%s) %s => %s" % (date, mark[5], descr)
             prevmark = mark
         add_item = Gtk.MenuItem(label=message)
         add_item.show()
@@ -452,10 +488,10 @@ class GeoFamily(GeoGraphyView):
                    None, event.button, event.time)
         return 1
 
-    def add_specific_menu(self, menu, event, lat, lon): 
-        """ 
+    def add_specific_menu(self, menu, event, lat, lon):
+        """
         Add specific entry to the navigation menu.
-        """ 
+        """
         return
 
     def get_default_gramplets(self):
